searchData={"items":[{"type":"module","title":"Cldr.Unit","doc":"Supports the CLDR Units definitions which provide for the localization of many\nunit types.\n\nThe primary public API defines:\n\n* `Cldr.Unit.to_string/3` which, given a unit or unit list will\n  output a localized string\n\n* `Cldr.Unit.known_units/0` identifies the available units for localization\n\n* `Cldr.Unit.{add, sub, mult, div}/2` to support basic unit mathematics between\n  units of compatible type (like length or volume)\n\n* `Cldr.Unit.compare/2` to compare one unit to another unit as long as they\n  are convertible.\n\n* `Cldr.Unit.convert/2` to convert one unit to another unit as long as they\n  are convertible.\n\n* `Cldr.Unit.localize/3` will convert a unit into the units preferred for a\n  given locale and usage\n\n* `Cldr.Unit.preferred_units/3` which, for a given unit and locale,\n  will return a list of preferred units that can be applied to\n  `Cldr.Unit.decompose/2`\n\n* `Cldr.Unit.decompose/2` to take a unit and return a list of units decomposed\n  by a list of smaller units.","ref":"Cldr.Unit.html"},{"type":"function","title":"Cldr.Unit.add/2","doc":"","ref":"Cldr.Unit.html#add/2"},{"type":"function","title":"Cldr.Unit.add!/2","doc":"","ref":"Cldr.Unit.html#add!/2"},{"type":"function","title":"Cldr.Unit.base_unit/1","doc":"Returns the base unit for a given unit.","ref":"Cldr.Unit.html#base_unit/1"},{"type":"function","title":"Argument - Cldr.Unit.base_unit/1","doc":"* `unit` is either a `t:Cldr.Unit.t/0`, an `atom` or\n  a `t:String.t/0`","ref":"Cldr.Unit.html#base_unit/1-argument"},{"type":"function","title":"Returns - Cldr.Unit.base_unit/1","doc":"* `{:ok, base_unit}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.html#base_unit/1-returns"},{"type":"function","title":"Example - Cldr.Unit.base_unit/1","doc":"iex> Cldr.Unit.base_unit :square_kilometer\n    {:ok, :square_meter}\n\n    iex> Cldr.Unit.base_unit :square_table\n    {:error, {Cldr.UnknownUnitError, \"Unknown unit was detected at \\\"table\\\"\"}}","ref":"Cldr.Unit.html#base_unit/1-example"},{"type":"function","title":"Cldr.Unit.base_unit_category_map/0","doc":"Returns a mapping of base units to their respective\nunit categories.\n\nBase units are a common unit for a given unit\ncategory which are used in two scenarios:\n\n1. When converting between units.  If two units\n  have the same base unit they can be converted\n  to each other. See `Cldr.Unit.Conversion`.\n\n2. When identifying the preferred units for a given\n  locale or territory, the base unit is used to\n  aid identification of preferences for given use\n  cases. See `Cldr.Unit.Preference`.","ref":"Cldr.Unit.html#base_unit_category_map/0"},{"type":"function","title":"Example - Cldr.Unit.base_unit_category_map/0","doc":"=> Cldr.Unit.base_unit_category_map\n    %{\n      \"kilogram_square_meter_per_cubic_second_ampere\" => :voltage,\n      \"kilogram_meter_per_meter_square_second\" => :torque,\n      \"square_meter\" => :area,\n      \"kilogram\" => :mass,\n      \"kilogram_square_meter_per_square_second\" => :energy,\n      \"revolution\" => :angle,\n      \"candela_per_square_meter\" => :luminance,\n      ...\n    }","ref":"Cldr.Unit.html#base_unit_category_map/0-example"},{"type":"function","title":"Cldr.Unit.base_units/0","doc":"Returns a mapping from unit categories to the\nbase unit.","ref":"Cldr.Unit.html#base_units/0"},{"type":"function","title":"Cldr.Unit.compare/2","doc":"","ref":"Cldr.Unit.html#compare/2"},{"type":"function","title":"Cldr.Unit.compatible?/2","doc":"Returns a boolean indicating if two units are\nof the same unit category.","ref":"Cldr.Unit.html#compatible?/2"},{"type":"function","title":"Arguments - Cldr.Unit.compatible?/2","doc":"* `unit_1` and `unit_2` are any units returned by\n  `Cldr.Unit.new/2` or a valid unit name.","ref":"Cldr.Unit.html#compatible?/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.compatible?/2","doc":"* `true` or `false`","ref":"Cldr.Unit.html#compatible?/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.compatible?/2","doc":"iex> Cldr.Unit.compatible? :foot, :meter\n    true\n\n    iex> Cldr.Unit.compatible? Cldr.Unit.new!(:foot, 23), :meter\n    true\n\n    iex> Cldr.Unit.compatible? :foot, :liter\n    false\n\n    iex> Cldr.Unit.compatible? \"light_year_per_second\", \"meter_per_gallon\"\n    false","ref":"Cldr.Unit.html#compatible?/2-examples"},{"type":"function","title":"Cldr.Unit.convert/2","doc":"","ref":"Cldr.Unit.html#convert/2"},{"type":"function","title":"Cldr.Unit.convert!/2","doc":"","ref":"Cldr.Unit.html#convert!/2"},{"type":"function","title":"Cldr.Unit.decompose/3","doc":"Decomposes a unit into subunits.\n\nAny list compatible units can be provided\nhowever a list of units of decreasing scale\nis recommended.  For example `[:foot, :inch]`\nor `[:kilometer, :meter, :centimeter, :millimeter]`","ref":"Cldr.Unit.html#decompose/3"},{"type":"function","title":"Arguments - Cldr.Unit.decompose/3","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`\n\n* `unit_list` is a list of valid units (one or\n  more from the list returned by `Cldr.Unit.known_units/0`. All\n  units must be from the same unit category.\n\n* `format_options` is a Keyword list of options\n  that is added to the *last* unit in `unit_list`.\n  The `format_options` will be applied when calling\n  `Cldr.Unit.to_string/3` on the `unit`. The\n  default is `[]`.","ref":"Cldr.Unit.html#decompose/3-arguments"},{"type":"function","title":"Returns - Cldr.Unit.decompose/3","doc":"* a list of units after decomposition or an error\n  tuple","ref":"Cldr.Unit.html#decompose/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.decompose/3","doc":"iex> u = Cldr.Unit.new!(10.3, :foot)\n    iex> Cldr.Unit.decompose u, [:foot, :inch]\n    [Cldr.Unit.new!(:foot, 10), Cldr.Unit.new!(:inch, \"3.6\")]\n\n    iex> u = Cldr.Unit.new!(:centimeter, 1111)\n    iex> Cldr.Unit.decompose u, [:kilometer, :meter, :centimeter, :millimeter]\n    [Cldr.Unit.new!(:meter, 11), Cldr.Unit.new!(:centimeter, 11)]","ref":"Cldr.Unit.html#decompose/3-examples"},{"type":"function","title":"Cldr.Unit.default_style/0","doc":"Returns the default formatting style.","ref":"Cldr.Unit.html#default_style/0"},{"type":"function","title":"Example - Cldr.Unit.default_style/0","doc":"iex> Cldr.Unit.default_style()\n    :long","ref":"Cldr.Unit.html#default_style/0-example"},{"type":"function","title":"Cldr.Unit.display_name/2","doc":"Returns the localized display name\nfor a unit.\n\nThe returned text is generally suitable\nfor including in UI elements such as\nselection boxes.","ref":"Cldr.Unit.html#display_name/2"},{"type":"function","title":"Arguments - Cldr.Unit.display_name/2","doc":"* `unit` is any `t:Cldr.Unit.t/0` or any\n  unit name returned by `Cldr.Unit.known_units/0`.\n\n* `options` is a keyword list of options.","ref":"Cldr.Unit.html#display_name/2-arguments"},{"type":"function","title":"Options - Cldr.Unit.display_name/2","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `:style` is one of those returned by `Cldr.Unit.available_styles`.\n  The current styles are `:long`, `:short` and `:narrow`.\n  The default is `style: :long`.","ref":"Cldr.Unit.html#display_name/2-options"},{"type":"function","title":"Examples - Cldr.Unit.display_name/2","doc":"iex> Cldr.Unit.display_name :liter\n    \"liters\"\n\n    iex> Cldr.Unit.display_name :liter, locale: \"fr\"\n    \"litres\"\n\n    iex> Cldr.Unit.display_name :liter, locale: \"fr\", style: :short\n    \"l\"","ref":"Cldr.Unit.html#display_name/2-examples"},{"type":"function","title":"Cldr.Unit.div/2","doc":"","ref":"Cldr.Unit.html#div/2"},{"type":"function","title":"Cldr.Unit.div!/2","doc":"","ref":"Cldr.Unit.html#div!/2"},{"type":"function","title":"Cldr.Unit.from_map/1","doc":"Returns a new `Unit.t` struct from a map.\n\nA map representation of a unit may be generated\nfrom json or other external format data.\n\nThe map provided must have the keys `unit` and\n`value` in either `String.t` or `atom` (both keys\nmust be of the same type).\n\n`value` must be either an integer, a float or a map\nrepresentation of a rational number. A rational number\nmap has the keys `numerator` and `denominator` in either\n`String.t` or `atom` format (both keys must be of\nthe same type).","ref":"Cldr.Unit.html#from_map/1"},{"type":"function","title":"Arguments - Cldr.Unit.from_map/1","doc":"* `map` is a map with the keys `unit` and `value`","ref":"Cldr.Unit.html#from_map/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.from_map/1","doc":"* `{:ok, unit}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.html#from_map/1-returns"},{"type":"function","title":"Examples - Cldr.Unit.from_map/1","doc":"Cldr.Unit.from_map %{value: 1, unit: \"kilogram\"}\n    => {:ok, #Cldr.Unit<:kilogram, 1>}\n\n    Cldr.Unit.from_map %{value: %{numerator: 3, denominator: 4}, unit: \"kilogram\"}\n    => {:ok, #Cldr.Unit<:kilogram, 3 <|> 4>}\n\n    Cldr.Unit.from_map %{\"value\" => 1, \"unit\" => \"kilogram\"}\n    => {:ok, #Cldr.Unit<:kilogram, 1>}","ref":"Cldr.Unit.html#from_map/1-examples"},{"type":"function","title":"Cldr.Unit.grammatical_gender/2","doc":"Return the grammatical gender for a\nunit.","ref":"Cldr.Unit.html#grammatical_gender/2"},{"type":"function","title":"Arguments - Cldr.Unit.grammatical_gender/2","doc":"","ref":"Cldr.Unit.html#grammatical_gender/2-arguments"},{"type":"function","title":"Options - Cldr.Unit.grammatical_gender/2","doc":"","ref":"Cldr.Unit.html#grammatical_gender/2-options"},{"type":"function","title":"Returns - Cldr.Unit.grammatical_gender/2","doc":"","ref":"Cldr.Unit.html#grammatical_gender/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.grammatical_gender/2","doc":"","ref":"Cldr.Unit.html#grammatical_gender/2-examples"},{"type":"function","title":"Cldr.Unit.grammatical_gender_error/2","doc":"","ref":"Cldr.Unit.html#grammatical_gender_error/2"},{"type":"function","title":"Cldr.Unit.invert/1","doc":"Inverts a unit\n\nOnly \"per\" units can be inverted.","ref":"Cldr.Unit.html#invert/1"},{"type":"function","title":"Cldr.Unit.known_grammatical_cases/0","doc":"Returns a list of the known grammatical\ncases.\n\nA grammatical case can be provided as an option to\n`Cldr.Unit.to_string/2` in order to localise a unit\nappropriate to the context in which it is used.","ref":"Cldr.Unit.html#known_grammatical_cases/0"},{"type":"function","title":"Example - Cldr.Unit.known_grammatical_cases/0","doc":"iex> Cldr.Unit.known_grammatical_cases()\n    [\n      :abessive,\n      :ablative,\n      :accusative,\n      :adessive,\n      :allative,\n      :causal,\n      :comitative,\n      :dative,\n      :delative,\n      :elative,\n      :ergative,\n      :genitive,\n      :illative,\n      :inessive,\n      :instrumental,\n      :locative,\n      :localtivecopulative,\n      :nominative,\n      :oblique,\n      :partitive,\n      :prepositional,\n      :sociative,\n      :sublative,\n      :superessive,\n      :terminative,\n      :translative,\n      :vocative\n    ]","ref":"Cldr.Unit.html#known_grammatical_cases/0-example"},{"type":"function","title":"Cldr.Unit.known_grammatical_genders/0","doc":"Returns a list of the known grammatical genders.\n\nA gender can be provided as an option to\n`Cldr.Unit.to_string/2` in order to localise a unit\nappropriate to the context in which it is used.","ref":"Cldr.Unit.html#known_grammatical_genders/0"},{"type":"function","title":"Example - Cldr.Unit.known_grammatical_genders/0","doc":"iex> Cldr.Unit.known_grammatical_genders()\n    [\n      :animate,\n      :inanimate,\n      :personal,\n      :common,\n      :feminine,\n      :masculine,\n      :neuter\n    ]","ref":"Cldr.Unit.html#known_grammatical_genders/0-example"},{"type":"function","title":"Cldr.Unit.known_measurement_systems/0","doc":"Return a list of known measurement systems.","ref":"Cldr.Unit.html#known_measurement_systems/0"},{"type":"function","title":"Example - Cldr.Unit.known_measurement_systems/0","doc":"iex> Cldr.Unit.known_measurement_systems()\n    [:astronomical, :jpsystem, :metric, :metric_adjacent, :person_age, :prefixable, :si, :si_acceptable, :uksystem, :ussystem]","ref":"Cldr.Unit.html#known_measurement_systems/0-example"},{"type":"function","title":"Cldr.Unit.known_styles/0","doc":"Returns the known styles for a unit.","ref":"Cldr.Unit.html#known_styles/0"},{"type":"function","title":"Example - Cldr.Unit.known_styles/0","doc":"iex> Cldr.Unit.known_styles()\n    [:long, :short, :narrow]","ref":"Cldr.Unit.html#known_styles/0-example"},{"type":"function","title":"Cldr.Unit.known_unit_categories/0","doc":"Returns a list of the known unit categories.","ref":"Cldr.Unit.html#known_unit_categories/0"},{"type":"function","title":"Example - Cldr.Unit.known_unit_categories/0","doc":"iex> Cldr.Unit.known_unit_categories()\n    [:acceleration, :angle, :area, :concentr, :consumption, :digital,\n     :duration, :electric, :energy, :force, :frequency, :graphics, :length, :light, :mass,\n     :power, :pressure, :speed, :temperature, :torque, :volume]","ref":"Cldr.Unit.html#known_unit_categories/0-example"},{"type":"function","title":"Cldr.Unit.known_units/0","doc":"Returns the known units that are directly\ntranslatable.\n\nThese units have localised content in CLDR\nand are used as a key to retrieving that\ncontent.","ref":"Cldr.Unit.html#known_units/0"},{"type":"function","title":"Example - Cldr.Unit.known_units/0","doc":"=> Cldr.Unit.known_units\n    [:acre, :acre_foot, :ampere, :arc_minute, :arc_second, :astronomical_unit, :bit,\n     :bushel, :byte, :calorie, :carat, :celsius, :centiliter, :centimeter, :century,\n     :cubic_centimeter, :cubic_foot, :cubic_inch, :cubic_kilometer, :cubic_meter,\n     :cubic_mile, :cubic_yard, :cup, :cup_metric, :day, :deciliter, :decimeter,\n     :degree, :fahrenheit, :fathom, :fluid_ounce, :foodcalorie, :foot, :furlong,\n     :g_force, :gallon, :gallon_imperial, :generic, :gigabit, :gigabyte, :gigahertz,\n     :gigawatt, :gram, :hectare, :hectoliter, :hectopascal, :hertz, :horsepower,\n     :hour, :inch, ...]","ref":"Cldr.Unit.html#known_units/0-example"},{"type":"function","title":"Cldr.Unit.known_units_by_category/0","doc":"Returns the units that are defined for\na given category (such as :volume, :length)\n\nSee also `Cldr.Unit.known_unit_categories/0`.","ref":"Cldr.Unit.html#known_units_by_category/0"},{"type":"function","title":"Example - Cldr.Unit.known_units_by_category/0","doc":"=> Cldr.Unit.known_units_by_category\n    %{\n      acceleration: [:g_force, :meter_per_square_second],\n      angle: [:arc_minute, :arc_second, :degree, :radian, :revolution],\n      area: [:acre, :dunam, :hectare, :square_centimeter, :square_foot,\n       :square_inch, :square_kilometer, :square_meter, :square_mile, :square_yard],\n      concentr: [:karat, :milligram_per_deciliter, :millimole_per_liter, :mole,\n       :percent, :permille, :permillion, :permyriad], ...\n     }","ref":"Cldr.Unit.html#known_units_by_category/0-example"},{"type":"function","title":"Cldr.Unit.known_units_for_category/1","doc":"Returns the list of units defined for a given\ncategory.","ref":"Cldr.Unit.html#known_units_for_category/1"},{"type":"function","title":"Arguments - Cldr.Unit.known_units_for_category/1","doc":"* `category` is any unit category returned by\n  `Cldr.Unit.known_unit_categories/0`.\n\nSee also `Cldr.Unit.known_units_by_category/0`.","ref":"Cldr.Unit.html#known_units_for_category/1-arguments"},{"type":"function","title":"Example - Cldr.Unit.known_units_for_category/1","doc":"=> Cldr.Unit.known_units_for_category :volume\n    {\n      :ok,\n      [\n        :cubic_centimeter,\n        :centiliter,\n        :hectoliter,\n        :cubic_kilometer,\n        :acre_foot,\n        ...\n      ]\n    }","ref":"Cldr.Unit.html#known_units_for_category/1-example"},{"type":"function","title":"Cldr.Unit.localize/1","doc":"Localizes a unit according to the current\nprocesses locale and backend.\n\nThe current process's locale is set with\n`Cldr.put_locale/1`.\n\nSee `Cldr.Unit.localize/3` for further\ndetails.","ref":"Cldr.Unit.html#localize/1"},{"type":"function","title":"Cldr.Unit.localize/3","doc":"Localizes a unit according to a territory\n\nA territory can be derived from a `t:Cldr.Locale.locale_name`\nor `t:Cldr.LangaugeTag`.\n\nUse this function if you have a unit which\nshould be presented in a user interface using\nunits relevant to the audience. For example, a\nunit `#Cldr.Unit100, :meter>` might be better\npresented to a US audience as `#Cldr.Unit<328, :foot>`.","ref":"Cldr.Unit.html#localize/3"},{"type":"function","title":"Arguments - Cldr.Unit.localize/3","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.\n\n* `options` is a keyword list of options","ref":"Cldr.Unit.html#localize/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.localize/3","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `backend.get_locale/0`.\n\n* `:territory` is any valid territory code returned by\n  `Cldr.known_territories/0`. The default is the territory defined\n  as part of the `:locale`. The option `:territory` has a precedence\n  over the territory in a locale.\n\n* `:usage` is the way in which the unit is intended\n  to be used.  The available `usage` varyies according\n  to the unit category.  See `Cldr.Unit.preferred_units/3`.","ref":"Cldr.Unit.html#localize/3-options"},{"type":"function","title":"Examples - Cldr.Unit.localize/3","doc":"iex> unit = Cldr.Unit.new!(1.83, :meter)\n    iex> Cldr.Unit.localize(unit, usage: :person_height, territory: :US)\n    [\n      Cldr.Unit.new!(:foot, 6, usage: :person_height),\n      Cldr.Unit.new!(:inch, \"0.04724409448818897637795275598\", usage: :person_height)\n    ]","ref":"Cldr.Unit.html#localize/3-examples"},{"type":"function","title":"Cldr.Unit.maybe_new/3","doc":"","ref":"Cldr.Unit.html#maybe_new/3"},{"type":"function","title":"Cldr.Unit.measurement_system?/2","doc":"Returns a boolean indicating if a given\nunit belongs to one or more measurement\nsystems.\n\nWhen a list or more than one measurement\nsystem is provided, the test is one of\ninclusion. That is, if the unit belongs to\nany of the provided measurement systems\nthe return is `true`.","ref":"Cldr.Unit.html#measurement_system?/2"},{"type":"function","title":"Arguments - Cldr.Unit.measurement_system?/2","doc":"* `system` is any measurement system or list\n  of measurement systems returned by\n  `Cldr.Unit.known_measurement_systems/0`","ref":"Cldr.Unit.html#measurement_system?/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.measurement_system?/2","doc":"* `true` or `false` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Unit.html#measurement_system?/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.measurement_system?/2","doc":"iex> Cldr.Unit.measurement_system? :foot, :uksystem\n    true\n\n    iex> Cldr.Unit.measurement_system? :foot, [:uksystem, :ussystem]\n    true\n\n    iex> Cldr.Unit.measurement_system? :foot, [:metric]\n    false\n\n    iex> Cldr.Unit.measurement_system? :invalid, [:metric]\n    {:error, {Cldr.UnknownUnitError, \"The unit :invalid is not known.\"}}","ref":"Cldr.Unit.html#measurement_system?/2-examples"},{"type":"function","title":"Cldr.Unit.measurement_system_for_territory/2","doc":"Returns the default measurement system for a territory\nand a given system key.","ref":"Cldr.Unit.html#measurement_system_for_territory/2"},{"type":"function","title":"Arguments - Cldr.Unit.measurement_system_for_territory/2","doc":"* `territory` is any valid territory returned by\n  `Cldr.validate_territory/1`\n\n* `key` is any measurement system key.\n  The known keys are `:default`, `:temperature`\n  and `:paper_size`. The default key is `:default`.","ref":"Cldr.Unit.html#measurement_system_for_territory/2-arguments"},{"type":"function","title":"Examples - Cldr.Unit.measurement_system_for_territory/2","doc":"iex> Cldr.Unit.measurement_system_for_territory :US\n    :ussystem\n\n    iex> Cldr.Unit.measurement_system_for_territory :GB\n    :uksystem\n\n    iex> Cldr.Unit.measurement_system_for_territory :AU\n    :metric\n\n    iex> Cldr.Unit.measurement_system_for_territory :US, :temperature\n    :ussystem\n\n    iex> Cldr.Unit.measurement_system_for_territory :GB, :temperature\n    :uksystem\n\n    iex> Cldr.Unit.measurement_system_for_territory :GB, :volume\n    {:error,\n     {Cldr.Unit.InvalidSystemKeyError,\n      \"The key :volume is not known. Valid keys are :default, :paper_size and :temperature\"}}","ref":"Cldr.Unit.html#measurement_system_for_territory/2-examples"},{"type":"function","title":"Cldr.Unit.measurement_system_from_locale/2","doc":"Determines the preferred measurement system\nfrom a locale.\n\nSee also `Cldr.Unit.known_measurement_systems/0`.","ref":"Cldr.Unit.html#measurement_system_from_locale/2"},{"type":"function","title":"Arguments - Cldr.Unit.measurement_system_from_locale/2","doc":"* `locale` is any valid locale name returned by\n  `Cldr.known_locale_names/0` or a `t:Cldr.LanguageTag`\n  struct.  The default is `Cldr.get_locale/0`.\n\n* `key` is any measurement system key.\n  The known keys are `:default`, `:temperature`\n  and `:paper_size`. The default key is `:default`.","ref":"Cldr.Unit.html#measurement_system_from_locale/2-arguments"},{"type":"function","title":"Examples - Cldr.Unit.measurement_system_from_locale/2","doc":"iex> Cldr.Unit.measurement_system_from_locale \"en\"\n    :ussystem\n\n    iex> Cldr.Unit.measurement_system_from_locale \"en-GB\"\n    :uksystem\n\n    iex> Cldr.Unit.measurement_system_from_locale \"en-AU\"\n    :metric\n\n    iex> Cldr.Unit.measurement_system_from_locale \"en-AU-u-ms-ussystem\"\n    :ussystem\n\n    iex> Cldr.Unit.measurement_system_from_locale \"en-GB\", :temperature\n    :uksystem\n\n    iex> Cldr.Unit.measurement_system_from_locale \"en-AU\", :paper_size\n    :a4\n\n    iex> Cldr.Unit.measurement_system_from_locale \"en-GB\", :invalid\n    {:error,\n     {Cldr.Unit.InvalidSystemKeyError,\n      \"The key :invalid is not known. Valid keys are :default, :paper_size and :temperature\"}}","ref":"Cldr.Unit.html#measurement_system_from_locale/2-examples"},{"type":"function","title":"Cldr.Unit.measurement_system_from_locale/3","doc":"","ref":"Cldr.Unit.html#measurement_system_from_locale/3"},{"type":"function","title":"Cldr.Unit.measurement_system_units/1","doc":"Returns the list of units defined in a given\nmeasurement system.","ref":"Cldr.Unit.html#measurement_system_units/1"},{"type":"function","title":"Arguments - Cldr.Unit.measurement_system_units/1","doc":"* `system` is any measurement system returned by\n  `Cldr.Unit.known_measurement_systems/0`","ref":"Cldr.Unit.html#measurement_system_units/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.measurement_system_units/1","doc":"* A list of translatable units as atoms or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Unit.html#measurement_system_units/1-returns"},{"type":"function","title":"Example - Cldr.Unit.measurement_system_units/1","doc":"=> Cldr.Unit.measurement_system_units :uksystem\n    [\n      :ton,\n      :inch,\n      :yard,\n      ...\n    ]","ref":"Cldr.Unit.html#measurement_system_units/1-example"},{"type":"function","title":"Cldr.Unit.measurement_systems/0","doc":"","ref":"Cldr.Unit.html#measurement_systems/0"},{"type":"function","title":"Cldr.Unit.measurement_systems_by_territory/0","doc":"Returns a map of measurement systems by territory.","ref":"Cldr.Unit.html#measurement_systems_by_territory/0"},{"type":"function","title":"Example - Cldr.Unit.measurement_systems_by_territory/0","doc":"=> Cldr.Unit.measurement_systems_by_territory\n    %{\n      KE: %{default: :metric, paper_size: :a4, temperature: :metric},\n      GU: %{default: :metric, paper_size: :a4, temperature: :metric},\n      ...\n    }","ref":"Cldr.Unit.html#measurement_systems_by_territory/0-example"},{"type":"function","title":"Cldr.Unit.measurement_systems_for_unit/1","doc":"Returns the measurement systems for a given\nunit.","ref":"Cldr.Unit.html#measurement_systems_for_unit/1"},{"type":"function","title":"Arguments - Cldr.Unit.measurement_systems_for_unit/1","doc":"* `unit` is any `t:Cldr.Unit.t/0` or any unit\n  returned by `Cldr.Unit.known_units/0` or a\n  string unit name.","ref":"Cldr.Unit.html#measurement_systems_for_unit/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.measurement_systems_for_unit/1","doc":"* A list of measurement systems to which\n  the `unit` belongs.\n\n* `{:error, {exception, message}}`","ref":"Cldr.Unit.html#measurement_systems_for_unit/1-returns"},{"type":"function","title":"Examples - Cldr.Unit.measurement_systems_for_unit/1","doc":"iex> Cldr.Unit.measurement_systems_for_unit :foot\n    [:uksystem, :ussystem]\n\n    iex> Cldr.Unit.measurement_systems_for_unit :meter\n    [:metric, :prefixable, :si]\n\n    iex> Cldr.Unit.measurement_systems_for_unit :invalid\n    {:error, {Cldr.UnknownUnitError, \"The unit :invalid is not known.\"}}","ref":"Cldr.Unit.html#measurement_systems_for_unit/1-examples"},{"type":"function","title":"Cldr.Unit.mult/2","doc":"","ref":"Cldr.Unit.html#mult/2"},{"type":"function","title":"Cldr.Unit.mult!/2","doc":"","ref":"Cldr.Unit.html#mult!/2"},{"type":"function","title":"Cldr.Unit.new/3","doc":"Returns a new `Unit.t` struct.","ref":"Cldr.Unit.html#new/3"},{"type":"function","title":"Arguments - Cldr.Unit.new/3","doc":"* `value` is any float, integer or `Decimal`\n\n* `unit` is any unit name returned by `Cldr.Unit.known_units/0`\n\n* `options` is Keyword list of options. The default\n  is `[]`","ref":"Cldr.Unit.html#new/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.new/3","doc":"* `:usage` is the intended use of the unit. This\n  is used during localization to convert the unit\n  to that appropriate for the unit category,\n  usage, target territory and unit value. The usage\n  must be defined for the unit's category. See\n  `Cldr.Unit.unit_category_usage/0` for the known\n  usage types for each category.","ref":"Cldr.Unit.html#new/3-options"},{"type":"function","title":"Returns - Cldr.Unit.new/3","doc":"* `unit` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Unit.html#new/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.new/3","doc":"iex> Cldr.Unit.new(23, :gallon)\n    {:ok, Cldr.Unit.new!(:gallon, 23)}\n\n    iex> Cldr.Unit.new(:gallon, 23)\n    {:ok, Cldr.Unit.new!(:gallon, 23)}\n\n    iex> Cldr.Unit.new(14, :gadzoots)\n    {:error, {Cldr.UnknownUnitError,\n      \"Unknown unit was detected at \\\"gadzoots\\\"\"}}\n\n    Cldr.Unit.new(:gallon, 23, usage: :fluid)\n    #=> {:ok, #Cldr.Unit<:gallon, 23, usage: :fluid, format_options: []>}","ref":"Cldr.Unit.html#new/3-examples"},{"type":"function","title":"Cldr.Unit.new!/3","doc":"Returns a new `Unit.t` struct or raises on error.","ref":"Cldr.Unit.html#new!/3"},{"type":"function","title":"Arguments - Cldr.Unit.new!/3","doc":"* `value` is any float, integer or `Decimal`\n\n* `unit` is any unit returned by `Cldr.Unit.known_units/0`","ref":"Cldr.Unit.html#new!/3-arguments"},{"type":"function","title":"Returns - Cldr.Unit.new!/3","doc":"* `unit` or\n\n* raises an exception","ref":"Cldr.Unit.html#new!/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.new!/3","doc":"iex> Cldr.Unit.new! 23, :gallon\n    Cldr.Unit.new!(:gallon, 23)\n\n    Cldr.Unit.new! 14, :gadzoots\n    ** (Cldr.UnknownUnitError) The unit :gadzoots is not known.\n        (ex_cldr_units) lib/cldr/unit.ex:57: Cldr.Unit.new!/2","ref":"Cldr.Unit.html#new!/3-examples"},{"type":"function","title":"Cldr.Unit.parse/2","doc":"Parse a string to create a new unit.\n\nThis function attempts to parse a string\ninto a `number` and `unit type`. If successful\nit attempts to create a new unit using\n`Cldr.Unit.new/3`.\n\nThe parsed `unit type` is aliased against all the\nknown unit names for a give locale (or the current\nlocale if no locale is specified). The known\naliases for unit types can be returned with\n`MyApp.Cldr.Unit.unit_strings_for/1` where `MyApp.Cldr`\nis the name of a backend module.","ref":"Cldr.Unit.html#parse/2"},{"type":"function","title":"Arguments - Cldr.Unit.parse/2","doc":"* `unit string` is any string to be parsed and if\n  possible used to create a new `t:Cldr.Unit.t/0`\n\n* `options` is a keyword list of options","ref":"Cldr.Unit.html#parse/2-arguments"},{"type":"function","title":"Options - Cldr.Unit.parse/2","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `:only` is a unit category or unit, or a list of unit categories and units.\n  The parsed unit must match one of the categories or units in order to\n  be valid. This is helpful when disambiguating parsed units. For example,\n  parsing \"2w\" could be either \"2 watts\" or \"2 weeks\". Specifying `only: :duration`\n  would return \"2 weeks\". Specifying `only: :power` would return\n  \"2 watts\"\n\n* `:except` is the oppostte of `:only`. The parsed unit must *not*\n  match the specified unit or category, or unit categories and units.","ref":"Cldr.Unit.html#parse/2-options"},{"type":"function","title":"Returns - Cldr.Unit.parse/2","doc":"* `{:ok, unit}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.html#parse/2-returns"},{"type":"function","title":"Notes - Cldr.Unit.parse/2","doc":"* When both `:only` and `:except` options are passed, both\n  conditions must be true in order to return a parsed result.\n\n* Only units returned by `Cldr.Unit.known_units/0` can be\n  used in the `:only` and `:except` filters.","ref":"Cldr.Unit.html#parse/2-notes"},{"type":"function","title":"Examples - Cldr.Unit.parse/2","doc":"iex> Cldr.Unit.parse \"1kg\"\n    Cldr.Unit.new(1, :kilogram)\n\n    iex> Cldr.Unit.parse \"1w\"\n    Cldr.Unit.new(1, :watt)\n\n    iex> Cldr.Unit.parse \"1w\", only: :duration\n    Cldr.Unit.new(1, :week)\n\n    iex> Cldr.Unit.parse \"1m\", only: [:year, :month, :day]\n    Cldr.Unit.new(1, :month)\n\n    iex> Cldr.Unit.parse \"1 tages\", locale: \"de\"\n    Cldr.Unit.new(1, :day)\n\n    iex> Cldr.Unit.parse \"1 tag\", locale: \"de\"\n    Cldr.Unit.new(1, :day)\n\n    iex> Cldr.Unit.parse(\"42 millispangels\")\n    {:error, {Cldr.UnknownUnitError, \"Unknown unit was detected at \\\"spangels\\\"\"}}","ref":"Cldr.Unit.html#parse/2-examples"},{"type":"function","title":"Cldr.Unit.parse!/2","doc":"Parse a string to create a new unit or\nraises an exception.\n\nThis function attempts to parse a string\ninto a `number` and `unit type`. If successful\nit attempts to create a new unit using\n`Cldr.Unit.new/3`.\n\nThe parsed `unit type` is un-aliased against all the\nknown unit names for a give locale (or the current\nlocale if no locale is specified). The known\naliases for unit types can be returned with\n`MyApp.Cldr.Unit.unit_strings_for/1` where `MyApp.Cldr`\nis the name of a backend module.","ref":"Cldr.Unit.html#parse!/2"},{"type":"function","title":"Arguments - Cldr.Unit.parse!/2","doc":"* `unit string` is any string to be parsed and if\n  possible used to create a new `t:Cldr.Unit.t/0`\n\n* `options` is a keyword list of options","ref":"Cldr.Unit.html#parse!/2-arguments"},{"type":"function","title":"Options - Cldr.Unit.parse!/2","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `:only` is a unit category or unit, or a list of unit categories and units.\n  The parsed unit must match one of the categories or units in order to\n  be valid. This is helpful when disambiguating parsed units. For example,\n  parsing \"2w\" could be either \"2 watts\" or \"2 weeks\". Specifying `only: :duration`\n  would return \"2 weeks\". Specifying `only: :power` would return\n  \"2 watts\"\n\n* `:except` is the oppostte of `:only`. The parsed unit must *not*\n  match the specified unit or category, or unit categories and units.","ref":"Cldr.Unit.html#parse!/2-options"},{"type":"function","title":"Notes - Cldr.Unit.parse!/2","doc":"* When both `:only` and `:except` options are passed, both\n  conditions must be true in order to return a parsed result.\n\n* Only units returned by `Cldr.Unit.known_units/0` can be\n  used in the `:only` and `:except` filters.","ref":"Cldr.Unit.html#parse!/2-notes"},{"type":"function","title":"Returns - Cldr.Unit.parse!/2","doc":"* `unit` or\n\n* raises an exception","ref":"Cldr.Unit.html#parse!/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.parse!/2","doc":"iex> Cldr.Unit.parse! \"1kg\"\n    Cldr.Unit.new!(1, :kilogram)\n\n    iex> Cldr.Unit.parse! \"1 tages\", locale: \"de\"\n    Cldr.Unit.new!(1, :day)\n\n    iex> Cldr.Unit.parse!(\"42 candela per lux\")\n    Cldr.Unit.new!(42, \"candela per lux\")\n\n    iex> Cldr.Unit.parse!(\"42 millispangels\")\n    ** (Cldr.UnknownUnitError) Unknown unit was detected at \"spangels\"","ref":"Cldr.Unit.html#parse!/2-examples"},{"type":"function","title":"Cldr.Unit.parse_unit_name/2","doc":"Parse a string to find a matching unit-atom.\n\nThis function attempts to parse a string and\nextract the `unit type`.\n\nThe parsed `unit type` is aliased against all the\nknown unit names for a give locale (or the current\nlocale if no locale is specified). The known\naliases for unit types can be returned with\n`MyApp.Cldr.Unit.unit_strings_for/1` where `MyApp.Cldr`\nis the name of a backend module.","ref":"Cldr.Unit.html#parse_unit_name/2"},{"type":"function","title":"Arguments - Cldr.Unit.parse_unit_name/2","doc":"* `unit_name_string` is any string to be parsed and converted into a `unit type`\n\n* `options` is a keyword list of options","ref":"Cldr.Unit.html#parse_unit_name/2-arguments"},{"type":"function","title":"Options - Cldr.Unit.parse_unit_name/2","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag` struct. The default is `Cldr.get_locale/0`\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `:only` is a unit category or unit, or a list of unit categories and units.\n  The parsed unit must match one of the categories or units in order to\n  be valid. This is helpful when disambiguating parsed units. For example,\n  parsing \"w\" could be either `:watt` or `:weeks`. Specifying `only: :duration`\n  would return `:weeks`. Specifying `only: :power` would return `:watt`\n\n* `:except` is the oppostte of `:only`. The parsed unit must *not*\n  match the specified unit or category, or unit categories and units.","ref":"Cldr.Unit.html#parse_unit_name/2-options"},{"type":"function","title":"Returns - Cldr.Unit.parse_unit_name/2","doc":"* `{:ok, unit_name}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.html#parse_unit_name/2-returns"},{"type":"function","title":"Notes - Cldr.Unit.parse_unit_name/2","doc":"* When both `:only` and `:except` options are passed, both\n  conditions must be true in order to return a parsed result.\n\n* Only units returned by `Cldr.Unit.known_units/0` can be\n  used in the `:only` and `:except` filters.","ref":"Cldr.Unit.html#parse_unit_name/2-notes"},{"type":"function","title":"Examples - Cldr.Unit.parse_unit_name/2","doc":"iex> Cldr.Unit.parse_unit_name \"kg\"\n    {:ok, :kilogram}\n\n    iex> Cldr.Unit.parse_unit_name \"w\"\n    {:ok, :watt}\n\n    iex> Cldr.Unit.parse_unit_name \"w\", only: :duration\n    {:ok, :week}\n\n    iex> Cldr.Unit.parse_unit_name \"m\", only: [:year, :month, :day]\n    {:ok, :month}\n\n    iex> Cldr.Unit.parse_unit_name \"tages\", locale: \"de\"\n    {:ok, :day}\n\n    iex> Cldr.Unit.parse_unit_name \"tag\", locale: \"de\"\n    {:ok, :day}\n\n    iex> Cldr.Unit.parse_unit_name(\"millispangels\")\n    {:error, {Cldr.UnknownUnitError, \"Unknown unit was detected at \\\"spangels\\\"\"}}","ref":"Cldr.Unit.html#parse_unit_name/2-examples"},{"type":"function","title":"Cldr.Unit.parse_unit_name!/2","doc":"Parse a string to find a matching unit-atom.\n\nThis function attempts to parse a string and\nextract the `unit type`.\n\nThe parsed `unit type` is aliased against all the\nknown unit names for a give locale (or the current\nlocale if no locale is specified). The known\naliases for unit types can be returned with\n`MyApp.Cldr.Unit.unit_strings_for/1` where `MyApp.Cldr`\nis the name of a backend module.","ref":"Cldr.Unit.html#parse_unit_name!/2"},{"type":"function","title":"Arguments - Cldr.Unit.parse_unit_name!/2","doc":"* `unit_name_string` is any string to be parsed and converted into a `unit type`\n\n* `options` is a keyword list of options","ref":"Cldr.Unit.html#parse_unit_name!/2-arguments"},{"type":"function","title":"Options - Cldr.Unit.parse_unit_name!/2","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag` struct. The default is `Cldr.get_locale/0`\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `:only` is a unit category or unit, or a list of unit categories and units.\n  The parsed unit must match one of the categories or units in order to\n  be valid. This is helpful when disambiguating parsed units. For example,\n  parsing \"w\" could be either `watts` or `:week`. Specifying `only: :duration`\n  would return `:week`. Specifying `only: :power` would return `:watts`\n\n* `:except` is the oppostte of `:only`. The parsed unit must *not*\n  match the specified unit or category, or unit categories and units.","ref":"Cldr.Unit.html#parse_unit_name!/2-options"},{"type":"function","title":"Returns - Cldr.Unit.parse_unit_name!/2","doc":"* `unit_name` or\n\n* raises an exception","ref":"Cldr.Unit.html#parse_unit_name!/2-returns"},{"type":"function","title":"Notes - Cldr.Unit.parse_unit_name!/2","doc":"* When both `:only` and `:except` options are passed, both\n  conditions must be true in order to return a parsed result.\n\n* Only units returned by `Cldr.Unit.known_units/0` can be\n  used in the `:only` and `:except` filters.","ref":"Cldr.Unit.html#parse_unit_name!/2-notes"},{"type":"function","title":"Examples - Cldr.Unit.parse_unit_name!/2","doc":"iex> Cldr.Unit.parse_unit_name! \"kg\"\n    :kilogram\n\n    iex> Cldr.Unit.parse_unit_name! \"w\"\n    :watt\n\n    iex> Cldr.Unit.parse_unit_name! \"w\", only: :duration\n    :week\n\n    iex> Cldr.Unit.parse_unit_name! \"m\", only: [:year, :month, :day]\n    :month\n\n    iex> Cldr.Unit.parse_unit_name! \"tages\", locale: \"de\"\n    :day\n\n    iex> Cldr.Unit.parse_unit_name! \"tag\", locale: \"de\"\n    :day\n\n    iex> Cldr.Unit.parse_unit_name!(\"millispangels\")\n    ** (Cldr.UnknownUnitError) Unknown unit was detected at \"spangels\"","ref":"Cldr.Unit.html#parse_unit_name!/2-examples"},{"type":"function","title":"Cldr.Unit.preferred_units/3","doc":"","ref":"Cldr.Unit.html#preferred_units/3"},{"type":"function","title":"Cldr.Unit.preferred_units!/3","doc":"","ref":"Cldr.Unit.html#preferred_units!/3"},{"type":"function","title":"Cldr.Unit.ratio_to_decimal/1","doc":"","ref":"Cldr.Unit.html#ratio_to_decimal/1"},{"type":"function","title":"Cldr.Unit.ratio_to_float/1","doc":"","ref":"Cldr.Unit.html#ratio_to_float/1"},{"type":"function","title":"Cldr.Unit.round/1","doc":"","ref":"Cldr.Unit.html#round/1"},{"type":"function","title":"Cldr.Unit.round/2","doc":"","ref":"Cldr.Unit.html#round/2"},{"type":"function","title":"Cldr.Unit.round/3","doc":"","ref":"Cldr.Unit.html#round/3"},{"type":"function","title":"Cldr.Unit.styles/0","doc":"","ref":"Cldr.Unit.html#styles/0"},{"type":"function","title":"Cldr.Unit.sub/2","doc":"","ref":"Cldr.Unit.html#sub/2"},{"type":"function","title":"Cldr.Unit.sub!/2","doc":"","ref":"Cldr.Unit.html#sub!/2"},{"type":"function","title":"Cldr.Unit.to_decimal_unit/1","doc":"Convert a float or integer `t:Unit` to a Decimal `t:Unit`.","ref":"Cldr.Unit.html#to_decimal_unit/1"},{"type":"function","title":"Cldr.Unit.to_float/1","doc":"","ref":"Cldr.Unit.html#to_float/1"},{"type":"function","title":"Cldr.Unit.to_float_unit/1","doc":"Convert a Decimal or integer `t:Unit` to a float `t:Unit`.","ref":"Cldr.Unit.html#to_float_unit/1"},{"type":"function","title":"Cldr.Unit.to_string/1","doc":"Formats a number into a string according to a unit definition\nfor the current process's locale and backend.\n\nThe current process's locale is set with\n`Cldr.put_locale/1`.\n\nSee `Cldr.Unit.to_string/3` for full details.","ref":"Cldr.Unit.html#to_string/1"},{"type":"function","title":"Cldr.Unit.to_string/3","doc":"Formats a number into a string according to a unit definition for a locale.\n\nDuring processing any `:format_options` of a `Unit.t()` are merged with\n`options` with `options` taking precedence.","ref":"Cldr.Unit.html#to_string/3"},{"type":"function","title":"Arguments - Cldr.Unit.to_string/3","doc":"* `list_or_number` is any number (integer, float or Decimal) or a\n  `t:Cldr.Unit.t/0` struct or a list of `t:Cldr.Unit.t/0` structs\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list of options.","ref":"Cldr.Unit.html#to_string/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.to_string/3","doc":"* `:unit` is any unit returned by `Cldr.Unit.known_units/0`. Ignored if\n  the number to be formatted is a `t:Cldr.Unit.t/0` struct\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`\n\n* `style` is one of those returned by `Cldr.Unit.styles`.\n  The current styles are `:long`, `:short` and `:narrow`.\n  The default is `style: :long`\n\n* `:grammatical_case` indicates that a localisation for the given\n  locale and given grammatical case should be used. See `Cldr.Unit.known_grammatical_cases/0`\n  for the list of known grammatical cases. Note that not all locales\n  define all cases. However all locales do define the `:nominative`\n  case, which is also the default.\n\n* `:gender` indicates that a localisation for the given\n  locale and given grammatical gender should be used.\n  See `Cldr.Unit.known_grammatical_genders/0`\n  for the list of known grammatical genders. Note that not all locales\n  define all genders.\n\n* `:list_options` is a keyword list of options for formatting a list\n  which is passed through to `Cldr.List.to_string/3`. This is only\n  applicable when formatting a list of units.\n\n* Any other options are passed to `Cldr.Number.to_string/2`\n  which is used to format the `number`","ref":"Cldr.Unit.html#to_string/3-options"},{"type":"function","title":"Returns - Cldr.Unit.to_string/3","doc":"* `{:ok, formatted_string}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Unit.html#to_string/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.to_string/3","doc":"iex> Cldr.Unit.to_string Cldr.Unit.new!(:gallon, 123), MyApp.Cldr\n    {:ok, \"123 gallons\"}\n\n    iex> Cldr.Unit.to_string Cldr.Unit.new!(:gallon, 1), MyApp.Cldr\n    {:ok, \"1 gallon\"}\n\n    iex> Cldr.Unit.to_string Cldr.Unit.new!(:gallon, 1), MyApp.Cldr, locale: \"af\"\n    {:ok, \"1 gelling\"}\n\n    iex> Cldr.Unit.to_string Cldr.Unit.new!(:gallon, 1), MyApp.Cldr, locale: \"bs\"\n    {:ok, \"1 galon\"}\n\n    iex> Cldr.Unit.to_string Cldr.Unit.new!(:gallon, 1234), MyApp.Cldr, format: :long\n    {:ok, \"1 thousand gallons\"}\n\n    iex> Cldr.Unit.to_string Cldr.Unit.new!(:gallon, 1234), MyApp.Cldr, format: :short\n    {:ok, \"1K gallons\"}\n\n    iex> Cldr.Unit.to_string Cldr.Unit.new!(:megahertz, 1234), MyApp.Cldr\n    {:ok, \"1,234 megahertz\"}\n\n    iex> Cldr.Unit.to_string Cldr.Unit.new!(:megahertz, 1234), MyApp.Cldr, style: :narrow\n    {:ok, \"1,234Mhz\"}\n\n    iex> unit = Cldr.Unit.new!(123, :foot)\n    iex> Cldr.Unit.to_string unit, MyApp.Cldr\n    {:ok, \"123 feet\"}\n\n    iex> Cldr.Unit.to_string 123, MyApp.Cldr, unit: :foot\n    {:ok, \"123 feet\"}\n\n    iex> Cldr.Unit.to_string Decimal.new(123), MyApp.Cldr, unit: :foot\n    {:ok, \"123 feet\"}\n\n    iex> Cldr.Unit.to_string 123, MyApp.Cldr, unit: :megabyte, locale: \"en\", style: :unknown\n    {:error, {Cldr.UnknownFormatError, \"The unit style :unknown is not known.\"}}","ref":"Cldr.Unit.html#to_string/3-examples"},{"type":"function","title":"Cldr.Unit.to_string!/1","doc":"Formats a number into a string according to a unit definition\nfor the current process's locale and backend or raises\non error.\n\nThe current process's locale is set with\n`Cldr.put_locale/1`.\n\nSee `Cldr.Unit.to_string!/3` for full details.","ref":"Cldr.Unit.html#to_string!/1"},{"type":"function","title":"Cldr.Unit.to_string!/3","doc":"Formats a number into a string according to a unit definition\nfor the current process's locale and backend or raises\non error.\n\nDuring processing any `:format_options` of a `t:Cldr.Unit.t/0` are merged with\n`options` with `options` taking precedence.","ref":"Cldr.Unit.html#to_string!/3"},{"type":"function","title":"Arguments - Cldr.Unit.to_string!/3","doc":"* `number` is any number (integer, float or Decimal) or a\n  `t:Cldr.Unit.t/0` struct\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list","ref":"Cldr.Unit.html#to_string!/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.to_string!/3","doc":"* `:unit` is any unit returned by `Cldr.Unit.known_units/0`. Ignored if\n  the number to be formatted is a `t:Cldr.Unit.t/0` struct\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`\n\n* `:style` is one of those returned by `Cldr.Unit.known_styles/0`.\n  The current styles are `:long`, `:short` and `:narrow`.\n  The default is `style: :long`\n\n* Any other options are passed to `Cldr.Number.to_string/2`\n  which is used to format the `number`","ref":"Cldr.Unit.html#to_string!/3-options"},{"type":"function","title":"Returns - Cldr.Unit.to_string!/3","doc":"* `formatted_string` or\n\n* raises an exception","ref":"Cldr.Unit.html#to_string!/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.to_string!/3","doc":"iex> Cldr.Unit.to_string! Cldr.Unit.new!(:gallon, 123), MyApp.Cldr\n    \"123 gallons\"\n\n    iex> Cldr.Unit.to_string! Cldr.Unit.new!(:gallon, 1), MyApp.Cldr\n    \"1 gallon\"\n\n    iex> Cldr.Unit.to_string! Cldr.Unit.new!(:gallon, 1), MyApp.Cldr, locale: \"af\"\n    \"1 gelling\"","ref":"Cldr.Unit.html#to_string!/3-examples"},{"type":"function","title":"Cldr.Unit.unit/0","doc":"","ref":"Cldr.Unit.html#unit/0"},{"type":"function","title":"Cldr.Unit.unit_categories/0","doc":"","ref":"Cldr.Unit.html#unit_categories/0"},{"type":"function","title":"Cldr.Unit.unit_category/1","doc":"Returns the units category for a given unit","ref":"Cldr.Unit.html#unit_category/1"},{"type":"function","title":"Options - Cldr.Unit.unit_category/1","doc":"* `unit` is either a `t:Cldr.Unit.t/0`, an `atom` or\n  a `t:String.t/0`","ref":"Cldr.Unit.html#unit_category/1-options"},{"type":"function","title":"Returns - Cldr.Unit.unit_category/1","doc":"* `{:ok, category}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Unit.html#unit_category/1-returns"},{"type":"function","title":"Examples - Cldr.Unit.unit_category/1","doc":"iex> Cldr.Unit.unit_category :pint_metric\n    {:ok, :volume}\n\n    iex> Cldr.Unit.unit_category :stone\n    {:ok, :mass}\n\n    iex> Cldr.Unit.unit_category :watt\n    {:ok, :power}\n\n    iex> Cldr.Unit.unit_category \"kilowatt hour\"\n    {:ok, :energy}\n\n    iex> Cldr.Unit.unit_category \"watt hour per light year\"\n    {:ok, :force}\n\n    iex> Cldr.Unit.unit_category \"watt per kilogram\"\n    {:error,\n     {Cldr.Unit.UnknownCategoryError,\n      \"The category for \\\"watt_per_kilogram\\\" is not known.\"}}","ref":"Cldr.Unit.html#unit_category/1-examples"},{"type":"function","title":"Cldr.Unit.unit_category_usage/0","doc":"Returns a mapping between Unit categories\nand the uses they define.","ref":"Cldr.Unit.html#unit_category_usage/0"},{"type":"function","title":"Example - Cldr.Unit.unit_category_usage/0","doc":"iex> Cldr.Unit.unit_category_usage()\n    %{\n      area: [:default, :floor, :geograph, :land],\n      concentration: [:blood_glucose, :default],\n      consumption: [:default, :vehicle_fuel],\n      duration: [:default, :media],\n      energy: [:default, :food],\n      length: [:default, :focal_length, :person, :person_height, :rainfall, :road,\n       :snowfall, :vehicle, :visiblty],\n      mass: [:default, :person],\n      mass_density: [:default],\n      power: [:default, :engine],\n      pressure: [:baromtrc, :default],\n      speed: [:default, :rainfall, :snowfall, :wind],\n      temperature: [:default, :weather],\n      volume: [:default, :fluid, :oil, :vehicle],\n      year_duration: [:default, :person_age]\n    }","ref":"Cldr.Unit.html#unit_category_usage/0-example"},{"type":"function","title":"Cldr.Unit.unit_type/1","doc":"","ref":"Cldr.Unit.html#unit_type/1"},{"type":"function","title":"Cldr.Unit.validate_grammatical_case/1","doc":"Validates a grammatical case and normalizes it to a\nstandard downcased atom form","ref":"Cldr.Unit.html#validate_grammatical_case/1"},{"type":"function","title":"Cldr.Unit.validate_grammatical_gender/2","doc":"Validates a grammatical gender and normalizes it to a\nstandard downcased atom form","ref":"Cldr.Unit.html#validate_grammatical_gender/2"},{"type":"function","title":"Cldr.Unit.validate_style/1","doc":"Validates a unit style and normalizes it to a\nstandard downcased atom form","ref":"Cldr.Unit.html#validate_style/1"},{"type":"function","title":"Cldr.Unit.validate_unit/1","doc":"Validates a unit name and normalizes it,\n\nA unit name can be expressed as:\n\n* an `atom()` in which case the unit must be\n  localizable in CLDR directly\n\n* or a `t:String.t/0` in which case it is parsed\n  into a list of composable subunits that\n  can be converted but are not guaranteed to\n  be output as a localized string.","ref":"Cldr.Unit.html#validate_unit/1"},{"type":"function","title":"Arguments - Cldr.Unit.validate_unit/1","doc":"* `unit_name` is an `atom()` or `t:String.t/0`, supplied\n  as is or as part of an `t:Cldr.Unit.t/0` struct.","ref":"Cldr.Unit.html#validate_unit/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.validate_unit/1","doc":"* `{:ok, canonical_unit_name, conversion}` where\n  `canonical_unit_name` is the normalized unit name\n  and `conversion` is an opaque structure used\n  to convert this this unit into its base unit or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.html#validate_unit/1-returns"},{"type":"function","title":"Notes - Cldr.Unit.validate_unit/1","doc":"A returned `unit_name` that is an atom is directly\nlocalisable (CLDR has translation data for the unit).\n\nA `unit_name` that is a `t:String.t/0` is composed of\none or more unit names that need to be resolved in\norder for the `unit_name` to be localised.\n\nThe difference is an implementation detail and should\nnot be of concern to the user of this library.","ref":"Cldr.Unit.html#validate_unit/1-notes"},{"type":"function","title":"Examples - Cldr.Unit.validate_unit/1","doc":"iex> Cldr.Unit.validate_unit :meter\n    {\n      :ok,\n      :meter,\n      [meter: %Cldr.Unit.Conversion{base_unit: [:meter], factor: 1, offset: 0}]\n    }\n\n    iex> Cldr.Unit.validate_unit \"meter\"\n    {:ok, :meter,\n     [meter: %Cldr.Unit.Conversion{base_unit: [:meter], factor: 1, offset: 0}]}\n\n    iex> Cldr.Unit.validate_unit \"miles_per_liter\"\n    {:error, {Cldr.UnknownUnitError, \"Unknown unit was detected at \\\"s\\\"\"}}\n\n    iex> Cldr.Unit.validate_unit \"mile_per_liter\"\n    {:ok, \"mile_per_liter\",\n     {[\n        mile: %Cldr.Unit.Conversion{\n          factor: Decimal.new(\"1609.3440\"),\n          offset: 0,\n          base_unit: [:meter]\n        }\n      ],\n      [\n        liter: %Cldr.Unit.Conversion{\n          factor: Decimal.new(\"0.001\"),\n          offset: 0,\n          base_unit: [:cubic_meter]\n        }\n      ]}}","ref":"Cldr.Unit.html#validate_unit/1-examples"},{"type":"function","title":"Cldr.Unit.value/1","doc":"Return the value of the Unit struct","ref":"Cldr.Unit.html#value/1"},{"type":"function","title":"Arguments - Cldr.Unit.value/1","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`","ref":"Cldr.Unit.html#value/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.value/1","doc":"* an integer, float or Decimal representing the amount\nof the unit","ref":"Cldr.Unit.html#value/1-returns"},{"type":"function","title":"Example - Cldr.Unit.value/1","doc":"iex> Cldr.Unit.value Cldr.Unit.new!(:kilogram, 23)\n    23","ref":"Cldr.Unit.html#value/1-example"},{"type":"function","title":"Cldr.Unit.zero/1","doc":"Returns a new unit of the same unit\ntype but with a zero value.","ref":"Cldr.Unit.html#zero/1"},{"type":"function","title":"Argument - Cldr.Unit.zero/1","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`","ref":"Cldr.Unit.html#zero/1-argument"},{"type":"function","title":"Example - Cldr.Unit.zero/1","doc":"iex> u = Cldr.Unit.new!(:foot, 23.3)\n    Cldr.Unit.new!(:foot, \"23.3\")\n    iex> Cldr.Unit.zero(u)\n    Cldr.Unit.new!(:foot, 0)","ref":"Cldr.Unit.html#zero/1-example"},{"type":"function","title":"Cldr.Unit.zero?/1","doc":"Returns a boolean indicating whether a given unit\nhas a zero value.","ref":"Cldr.Unit.html#zero?/1"},{"type":"function","title":"Argument - Cldr.Unit.zero?/1","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`","ref":"Cldr.Unit.html#zero?/1-argument"},{"type":"function","title":"Examples - Cldr.Unit.zero?/1","doc":"iex> u = Cldr.Unit.new!(:foot, 23.3)\n    Cldr.Unit.new!(:foot, 23.3)\n    iex> Cldr.Unit.zero?(u)\n    false\n\n    iex> u = Cldr.Unit.new!(:foot, 0)\n    Cldr.Unit.new!(:foot, 0)\n    iex> Cldr.Unit.zero?(u)\n    true","ref":"Cldr.Unit.html#zero?/1-examples"},{"type":"type","title":"Cldr.Unit.base_conversion/0","doc":"","ref":"Cldr.Unit.html#t:base_conversion/0"},{"type":"type","title":"Cldr.Unit.category/0","doc":"","ref":"Cldr.Unit.html#t:category/0"},{"type":"type","title":"Cldr.Unit.conversion/0","doc":"","ref":"Cldr.Unit.html#t:conversion/0"},{"type":"type","title":"Cldr.Unit.grammatical_case/0","doc":"","ref":"Cldr.Unit.html#t:grammatical_case/0"},{"type":"type","title":"Cldr.Unit.grammatical_gender/0","doc":"","ref":"Cldr.Unit.html#t:grammatical_gender/0"},{"type":"type","title":"Cldr.Unit.locale/0","doc":"","ref":"Cldr.Unit.html#t:locale/0"},{"type":"type","title":"Cldr.Unit.measurement_system/0","doc":"","ref":"Cldr.Unit.html#t:measurement_system/0"},{"type":"type","title":"Cldr.Unit.style/0","doc":"","ref":"Cldr.Unit.html#t:style/0"},{"type":"type","title":"Cldr.Unit.t/0","doc":"","ref":"Cldr.Unit.html#t:t/0"},{"type":"type","title":"Cldr.Unit.translatable_unit/0","doc":"","ref":"Cldr.Unit.html#t:translatable_unit/0"},{"type":"type","title":"Cldr.Unit.unit/0","doc":"","ref":"Cldr.Unit.html#t:unit/0"},{"type":"type","title":"Cldr.Unit.usage/0","doc":"","ref":"Cldr.Unit.html#t:usage/0"},{"type":"type","title":"Cldr.Unit.value/0","doc":"","ref":"Cldr.Unit.html#t:value/0"},{"type":"module","title":"Cldr.Unit.Additional","doc":"Additional domain-specific units can be defined\nto suit application requirements. In the context\nof `ex_cldr` there are two parts of configuring\nadditional units.\n\n1. Configure the unit, base unit and conversion in\n`config.exs`. This is a requirement since units are\ncompiled into code.\n\n2. Configure the localizations for the additional\nunit in a CLDR backend module.\n\nOnce configured, additional units act and behave\nlike any of the predefined units of measure defined\nby CLDR.","ref":"Cldr.Unit.Additional.html"},{"type":"module","title":"Configuring a unit in config.exs - Cldr.Unit.Additional","doc":"Under the application `:ex_cldr_units` define\na key `:additional_units` with the required\nunit definitions.  For example:\n```elixir\nconfig :ex_cldr_units, :additional_units,\n  vehicle: [base_unit: :unit, factor: 1, offset: 0, sort_before: :all],\n  person: [base_unit: :unit, factor: 1, offset: 0, sort_before: :all]\n```\nThis example defines two additional units: `:vehicle` and\n`:person`.  The keys `:base_unit`, and `:factor` are required.\nThe key `:offset` is optional and defaults to `0`. The\nkey `:sort_before` is optional and defaults to `:none`.","ref":"Cldr.Unit.Additional.html#module-configuring-a-unit-in-config-exs"},{"type":"module","title":"Configuration keys - Cldr.Unit.Additional","doc":"* `:base_unit` is the common denominator that is used\n  to support conversion between like units. It can be\n  any atom value. For example `:liter` is the base unit\n  for volume units, `:meter` is the base unit for length\n  units.\n\n* `:factor` is used to convert a unit to its base unit in\n  order to support conversion. When converting a unit to\n  another compatible unit, the unit is first multiplied by\n  this units factor then divided by the target units factor.\n\n* `:offset` is added to a unit after applying its base factor\n  in order to convert to another unit.\n\n* `:sort_before` determines where in this *base unit* sorts\n  relative to other base units.  Typically this is set to\n  `:all` in which case this base unit sorts before all other\n  base units or`:none` in which case this base unit sorted\n  after all other base units. The default is `:none`. If in\n  doubt, leave this key to its default.\n\n* `:systems` is list of measurement systems to which this\n  unit belongs. The known measurement systems are `:metric`,\n  `:uksystem` and `:ussystem`. The default is\n  `[:metric, :ussystem, :uksystem]`.","ref":"Cldr.Unit.Additional.html#module-configuration-keys"},{"type":"module","title":"Defining localizations - Cldr.Unit.Additional","doc":"Localizations are defined in a backend module through adding\n`use Cldr.Unit.Additional` to the top of the backend module\nand invoking `Cldr.Unit.Additional.unit_localization/4` for\neach localization.\n\nSee `Cldr.Unit.Additional.unit_localization/4` for further\ninformation.\n\nNote that one invocation of the macro is required for\neach combination of locale, style and unit. An exception\nwill be raised at runtime is a localization is expected\nbut is not found.","ref":"Cldr.Unit.Additional.html#module-defining-localizations"},{"type":"function","title":"Cldr.Unit.Additional.merge_base_units/3","doc":"","ref":"Cldr.Unit.Additional.html#merge_base_units/3"},{"type":"macro","title":"Cldr.Unit.Additional.unit_localization/4","doc":"Although defining a unit in `config.exs` is enough to create,\noperate on and serialize an additional unit, it cannot be\nlocalised without defining localizations in an `ex_cldr`\nbackend module.  For example:\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr.Unit.Additional\n\n  use Cldr,\n    locales: [\"en\", \"fr\", \"de\", \"bs\", \"af\", \"af-NA\", \"se-SE\"],\n    default_locale: \"en\",\n    providers: [Cldr.Number, Cldr.Unit, Cldr.List]\n\n  unit_localization(:person, \"en\", :long,\n    one: \"{0} person\",\n    other: \"{0} people\",\n    display_name: \"people\"\n  )\n\n  unit_localization(:person, \"en\", :short,\n    one: \"{0} per\",\n    other: \"{0} pers\",\n    display_name: \"people\"\n  )\n\n  unit_localization(:person, \"en\", :narrow,\n    one: \"{0} p\",\n    other: \"{0} p\",\n    display_name: \"p\"\n  )\nend\n```\n\nNote the additions to a typical `ex_cldr`\nbackend module:\n\n* `use Cldr.Unit.Additional` is required to\n  define additional units\n\n* use of the `unit_localization/4` macro in\n  order to define a localization.\n\nOne invocation of `unit_localization` should\nmade for each combination of unit, locale and\nstyle.","ref":"Cldr.Unit.Additional.html#unit_localization/4"},{"type":"macro","title":"Parameters to unit_localization/4 - Cldr.Unit.Additional.unit_localization/4","doc":"* `unit` is the name of the additional\nunit as an `atom`.\n\n* `locale` is the locale name for this\n  localization. It should be one of the locale\n  configured in this backend although this\n  cannot currently be confirmed at compile time.\n\n* `style` is one of `:long`, `:short`, or\n  `:narrow`.\n\n* `localizations` is a keyword like of localization\n  strings. Two keys - `:display_name` and `:other`\n  are mandatory. They represent the localizations for\n  a non-count display name and `:other` is the\n  localization for a unit when no other pluralization\n  is defined.","ref":"Cldr.Unit.Additional.html#unit_localization/4-parameters-to-unit_localization-4"},{"type":"macro","title":"Localisations - Cldr.Unit.Additional.unit_localization/4","doc":"Localization keyword list defines localizations that\nmatch the plural rules for a given locale. Plural rules\nfor a given number in a given locale resolve to one of\nsix keys:\n\n* `:zero`\n* `:one` (singular)\n* `:two` (dual)\n* `:few` (paucal)\n* `:many` (also used for fractions if they have a separate class)\n* `:other` (required—general plural form—also used if the language only has a single form)\n\nOnly the `:other` key is required. For english,\nproviding keys for `:one` and `:other` is enough. Other\nlanguages have different grammatical requirements.\n\nThe key `:display_name` is used by the function\n`Cldr.Unit.display_name/1` which is primarily used\nto support UI applications.","ref":"Cldr.Unit.Additional.html#unit_localization/4-localisations"},{"type":"module","title":"Cldr.Unit.Alias","doc":"Functions to manage unit name aliases","ref":"Cldr.Unit.Alias.html"},{"type":"function","title":"Cldr.Unit.Alias.alias/1","doc":"Un-aliases the provided unit if there\nis one or return the argument unchanged.","ref":"Cldr.Unit.Alias.html#alias/1"},{"type":"function","title":"Cldr.Unit.Alias.aliases/0","doc":"","ref":"Cldr.Unit.Alias.html#aliases/0"},{"type":"module","title":"Cldr.Unit.Backend","doc":"","ref":"Cldr.Unit.Backend.html"},{"type":"function","title":"Cldr.Unit.Backend.define_unit_module/1","doc":"","ref":"Cldr.Unit.Backend.html#define_unit_module/1"},{"type":"module","title":"Cldr.Unit.BaseUnit","doc":"Functions to support the base unit calculations\nfor a unit.\n\nBase unit equality is used to determine whether\na one unit can be converted to another","ref":"Cldr.Unit.BaseUnit.html"},{"type":"function","title":"Cldr.Unit.BaseUnit.canonical_base_unit/1","doc":"Returns the canonical base unit name\nfor a unit.\n\nThe base unit is the common unit through which\nconversions are passed.","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit/1"},{"type":"function","title":"Arguments - Cldr.Unit.BaseUnit.canonical_base_unit/1","doc":"* `unit_string` is any string representing\n  a unit such as `light_year_per_week`.","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.BaseUnit.canonical_base_unit/1","doc":"* `{:ok, canonical_base_unit}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit/1-returns"},{"type":"function","title":"Examples - Cldr.Unit.BaseUnit.canonical_base_unit/1","doc":"iex> Cldr.Unit.Parser.canonical_base_unit \"meter\"\n    {:ok, :meter}\n\n    iex> Cldr.Unit.Parser.canonical_base_unit \"meter meter\"\n    {:ok, :square_meter}\n\n    iex> Cldr.Unit.Parser.canonical_base_unit \"meter per kilogram\"\n    {:ok, \"meter_per_kilogram\"}\n\n    iex> Cldr.Unit.Parser.canonical_base_unit \"yottagram per mile scandinavian\"\n    {:ok, \"kilogram_per_meter\"}","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit/1-examples"},{"type":"function","title":"Cldr.Unit.BaseUnit.canonical_base_unit!/1","doc":"Returns the canonical base unit name\nfor a unit.\n\nThe base unit is the common unit through which\nconversions are passed.","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit!/1"},{"type":"function","title":"Arguments - Cldr.Unit.BaseUnit.canonical_base_unit!/1","doc":"* `unit_string` is any string representing\n  a unit such as `light_year_per_week`.","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit!/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.BaseUnit.canonical_base_unit!/1","doc":"* `canonical_base_unit` or\n\n* raises an exception","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit!/1-returns"},{"type":"function","title":"Examples - Cldr.Unit.BaseUnit.canonical_base_unit!/1","doc":"iex> Cldr.Unit.Parser.canonical_base_unit! \"meter\"\n    :meter\n\n    iex> Cldr.Unit.Parser.canonical_base_unit! \"meter meter\"\n    :square_meter\n\n    iex> Cldr.Unit.Parser.canonical_base_unit! \"meter per kilogram\"\n    \"meter_per_kilogram\"\n\n    iex> Cldr.Unit.Parser.canonical_base_unit! \"yottagram per mile scandinavian\"\n    \"kilogram_per_meter\"","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit!/1-examples"},{"type":"function","title":"Cldr.Unit.BaseUnit.do_canonical_base_unit/1","doc":"","ref":"Cldr.Unit.BaseUnit.html#do_canonical_base_unit/1"},{"type":"function","title":"Cldr.Unit.BaseUnit.do_reduce_factors/1","doc":"","ref":"Cldr.Unit.BaseUnit.html#do_reduce_factors/1"},{"type":"module","title":"Cldr.Unit.Conversion","doc":"Unit conversion functions for the units defined\nin `CLDR`.","ref":"Cldr.Unit.Conversion.html"},{"type":"function","title":"Cldr.Unit.Conversion.base_unit_and_conversion/1","doc":"Returns the base unit and the base unit\nconversionfor a given unit.","ref":"Cldr.Unit.Conversion.html#base_unit_and_conversion/1"},{"type":"function","title":"Argument - Cldr.Unit.Conversion.base_unit_and_conversion/1","doc":"* `unit` is either a `t:Cldr.Unit`, an `atom` or\n  a `t:String`","ref":"Cldr.Unit.Conversion.html#base_unit_and_conversion/1-argument"},{"type":"function","title":"Returns - Cldr.Unit.Conversion.base_unit_and_conversion/1","doc":"* `{:ok, base_unit, conversion}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.Conversion.html#base_unit_and_conversion/1-returns"},{"type":"function","title":"Example - Cldr.Unit.Conversion.base_unit_and_conversion/1","doc":"iex> Cldr.Unit.Conversion.base_unit_and_conversion :square_kilometer\n    {:ok, :square_meter,\n     [\n       {\"square_kilometer\",\n        %Cldr.Unit.Conversion{\n          factor: 1000000,\n          offset: 0,\n          base_unit: [:square, :meter]\n        }}\n     ]}\n\n    iex> Cldr.Unit.Conversion.base_unit_and_conversion :square_table\n    {:error, {Cldr.UnknownUnitError, \"Unknown unit was detected at \\\"table\\\"\"}}","ref":"Cldr.Unit.Conversion.html#base_unit_and_conversion/1-example"},{"type":"function","title":"Cldr.Unit.Conversion.conversion_for/2","doc":"Returns the conversion that calculates\nthe base unit into another unit or\nand error.","ref":"Cldr.Unit.Conversion.html#conversion_for/2"},{"type":"function","title":"Cldr.Unit.Conversion.convert/2","doc":"Convert one unit into another unit of the same\nunit type (length, volume, mass, ...)","ref":"Cldr.Unit.Conversion.html#convert/2"},{"type":"function","title":"Arguments - Cldr.Unit.Conversion.convert/2","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`.\n\n* `to_unit` is any unit name returned by `Cldr.Unit.known_units/0`.","ref":"Cldr.Unit.Conversion.html#convert/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Conversion.convert/2","doc":"* a `Unit.t` of the unit type `to_unit` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Unit.Conversion.html#convert/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.Conversion.convert/2","doc":"iex> Cldr.Unit.convert Cldr.Unit.new!(:mile, 1), :foot\n    {:ok, Cldr.Unit.new!(:foot, 5280)}\n\n    iex> Cldr.Unit.convert Cldr.Unit.new!(:mile, 1), :gallon\n    {:error, {Cldr.Unit.IncompatibleUnitsError,\n      \"Operations can only be performed between units with the same base unit. Received :mile and :gallon\"}}","ref":"Cldr.Unit.Conversion.html#convert/2-examples"},{"type":"function","title":"Cldr.Unit.Conversion.convert!/2","doc":"Convert one unit into another unit of the same\nunit type (length, volume, mass, ...) and raises\non a unit type mismatch.","ref":"Cldr.Unit.Conversion.html#convert!/2"},{"type":"function","title":"Arguments - Cldr.Unit.Conversion.convert!/2","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`.\n\n* `to_unit` is any unit name returned by `Cldr.Unit.known_units/0`.","ref":"Cldr.Unit.Conversion.html#convert!/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Conversion.convert!/2","doc":"* a `Unit.t` of the unit type `to_unit` or\n\n* raises an exception","ref":"Cldr.Unit.Conversion.html#convert!/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.Conversion.convert!/2","doc":"iex> Cldr.Unit.Conversion.convert!(Cldr.Unit.new!(:celsius, 0), :fahrenheit)\n    ...> |> Cldr.Unit.round\n    Cldr.Unit.new!(:fahrenheit, 32)\n\n    iex> Cldr.Unit.Conversion.convert!(Cldr.Unit.new!(:fahrenheit, 32), :celsius)\n    ...> |> Cldr.Unit.round\n    Cldr.Unit.new!(:celsius, 0)\n\n    Cldr.Unit.Conversion.convert Cldr.Unit.new!(:mile, 1), :gallon\n    ** (Cldr.Unit.IncompatibleUnitsError) Operations can only be performed between units of the same type. Received :mile and :gallon","ref":"Cldr.Unit.Conversion.html#convert!/2-examples"},{"type":"function","title":"Cldr.Unit.Conversion.convert_to_base_unit/1","doc":"Convert a unit into its base unit.\n\nFor example, the base unit for `length`\nis `meter`. The base unit is an\nintermediary unit used in all\nconversions.","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit/1"},{"type":"function","title":"Arguments - Cldr.Unit.Conversion.convert_to_base_unit/1","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Conversion.convert_to_base_unit/1","doc":"* `unit` converted to its base unit as a `t:Unit.t()` or\n\n* `{;error, {exception, reason}}` as an error","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit/1-returns"},{"type":"function","title":"Example - Cldr.Unit.Conversion.convert_to_base_unit/1","doc":"iex> unit = Cldr.Unit.new!(:kilometer, 10)\n    iex> Cldr.Unit.Conversion.convert_to_base_unit unit\n    {:ok, Cldr.Unit.new!(:meter, 10000)}","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit/1-example"},{"type":"function","title":"Cldr.Unit.Conversion.convert_to_base_unit!/1","doc":"Convert a unit into its base unit and\nraises on error.\n\nFor example, the base unit for `length`\nis `meter`. The base unit is an\nintermediary unit used in all\nconversions.","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit!/1"},{"type":"function","title":"Arguments - Cldr.Unit.Conversion.convert_to_base_unit!/1","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`.","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit!/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Conversion.convert_to_base_unit!/1","doc":"* `unit` converted to its base unit as a `t:Unit.t()` or\n\n* raises an exception","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit!/1-returns"},{"type":"function","title":"Example - Cldr.Unit.Conversion.convert_to_base_unit!/1","doc":"iex> unit = Cldr.Unit.new!(:kilometer, 10)\n    iex> Cldr.Unit.Conversion.convert_to_base_unit! unit\n    Cldr.Unit.new!(:meter, 10000)","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit!/1-example"},{"type":"function","title":"Cldr.Unit.Conversion.maybe_invert_value/2","doc":"","ref":"Cldr.Unit.Conversion.html#maybe_invert_value/2"},{"type":"type","title":"Cldr.Unit.Conversion.factor/0","doc":"","ref":"Cldr.Unit.Conversion.html#t:factor/0"},{"type":"type","title":"Cldr.Unit.Conversion.offset/0","doc":"","ref":"Cldr.Unit.Conversion.html#t:offset/0"},{"type":"type","title":"Cldr.Unit.Conversion.t/0","doc":"","ref":"Cldr.Unit.Conversion.html#t:t/0"},{"type":"module","title":"Cldr.Unit.Conversion.Options","doc":"Options structure for unit conversions","ref":"Cldr.Unit.Conversion.Options.html"},{"type":"type","title":"Cldr.Unit.Conversion.Options.t/0","doc":"","ref":"Cldr.Unit.Conversion.Options.html#t:t/0"},{"type":"module","title":"Cldr.Unit.Format","doc":"Functions for formatting a unit or unit range into\nan iolist or a string.","ref":"Cldr.Unit.Format.html"},{"type":"function","title":"Cldr.Unit.Format.grammar/2","doc":"Traverses the components of a unit\nand resolves a list of base units with\ntheir gramatical case and plural selector\ndefinitions for a given locale.\n\nThis function relies upon the internal\nrepresentation of units and grammatical features\nand is primarily for the support of\nformatting a function through `Cldr.Unit.to_string/2`.","ref":"Cldr.Unit.Format.html#grammar/2"},{"type":"function","title":"Arguments - Cldr.Unit.Format.grammar/2","doc":"* `unit` is a `t:Cldr.Unit.t/0` or a binary\n  unit string","ref":"Cldr.Unit.Format.html#grammar/2-arguments"},{"type":"function","title":"Options - Cldr.Unit.Format.grammar/2","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `t:Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.","ref":"Cldr.Unit.Format.html#grammar/2-options"},{"type":"function","title":"Returns - Cldr.Unit.Format.grammar/2","doc":"","ref":"Cldr.Unit.Format.html#grammar/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.Format.grammar/2","doc":"","ref":"Cldr.Unit.Format.html#grammar/2-examples"},{"type":"function","title":"Cldr.Unit.Format.to_iolist/1","doc":"Formats a number into an iolist according to a unit definition\nfor the current process's locale and backend.\n\nSee `Cldr.Unit.Format.to_iolist/3` for full details.","ref":"Cldr.Unit.Format.html#to_iolist/1"},{"type":"function","title":"Cldr.Unit.Format.to_iolist/3","doc":"Formats a number into an iolist according to a unit definition\nfor a locale.","ref":"Cldr.Unit.Format.html#to_iolist/3"},{"type":"function","title":"Arguments - Cldr.Unit.Format.to_iolist/3","doc":"* `list_or_unit` is any number (integer, float or Decimal) or a\n  `t:Cldr.Unit.t/0` struct or a list of `t:Cldr.Unit.t/0` structs or a\n  `t:Cldr.Unit.Range.t/0` struct.\n\n* `options` is a keyword list","ref":"Cldr.Unit.Format.html#to_iolist/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.Format.to_iolist/3","doc":"* `:unit` is any unit returned by `Cldr.Unit.known_units/0`. Ignored if\n  the number to be formatted is a `t:Cldr.Unit.t/0` struct\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`\n\n* `:style` is one of those returned by `Cldr.Unit.available_styles`.\n  The current styles are `:long`, `:short` and `:narrow`.\n  The default is `style: :long`\n\n* `:grammatical_case` indicates that a localisation for the given\n  locale and given grammatical case should be used. See `Cldr.Unit.known_grammatical_cases/0`\n  for the list of known grammatical cases. Note that not all locales\n  define all cases. However all locales do define the `:nominative`\n  case, which is also the default.\n\n* `:gender` indicates that a localisation for the given\n  locale and given grammatical gender should be used. See `Cldr.Unit.known_grammatical_genders/0`\n  for the list of known grammatical genders. Note that not all locales\n  define all genders.\n\n* `:list_options` is a keyword list of options for formatting a list\n  which is passed through to `Cldr.List.to_string/3`. This is only\n  applicable when formatting a list of units.\n\n* Any other options are passed to `Cldr.Number.to_string/2`\n  which is used to format the `number`","ref":"Cldr.Unit.Format.html#to_iolist/3-options"},{"type":"function","title":"Returns - Cldr.Unit.Format.to_iolist/3","doc":"* `{:ok, io_list}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Unit.Format.html#to_iolist/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.Format.to_iolist/3","doc":"iex> Cldr.Unit.Format.to_iolist Cldr.Unit.new!(:gallon, 123)\n    {:ok, [\"123\", \" gallons\"]}","ref":"Cldr.Unit.Format.html#to_iolist/3-examples"},{"type":"function","title":"Cldr.Unit.Format.to_iolist!/1","doc":"Formats a number into an iolist according to a unit definition\nfor the current process's locale and backend.\n\nSee `Cldr.Unit.Format.to_iolist!/3` for full details.","ref":"Cldr.Unit.Format.html#to_iolist!/1"},{"type":"function","title":"Cldr.Unit.Format.to_iolist!/3","doc":"Formats a unit using `to_iolist/3` but raises if there is\nan error.","ref":"Cldr.Unit.Format.html#to_iolist!/3"},{"type":"function","title":"Arguments - Cldr.Unit.Format.to_iolist!/3","doc":"* `number` is any number (integer, float or Decimal) or a\n  `t:Cldr.Unit.t/0` struct or a list of `t:Cldr.Unit.t/0` structs or a\n  `t:Cldr.Unit.Range.t/0` struct.\n\n* `options` is a keyword list","ref":"Cldr.Unit.Format.html#to_iolist!/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.Format.to_iolist!/3","doc":"* `:unit` is any unit returned by `Cldr.Unit.known_units/0`. Ignored if\n  the number to be formatted is a `t:Cldr.Unit.t/0` struct\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`\n\n* `:style` is one of those returned by `Cldr.Unit.known_styles/0`.\n  The current styles are `:long`, `:short` and `:narrow`.\n  The default is `style: :long`.\n\n* `:grammatical_case` indicates that a localisation for the given\n  locale and given grammatical case should be used. See `Cldr.Unit.known_grammatical_cases/0`\n  for the list of known grammatical cases. Note that not all locales\n  define all cases. However all locales do define the `:nominative`\n  case, which is also the default.\n\n* `:gender` indicates that a localisation for the given\n  locale and given grammatical gender should be used. See `Cldr.Unit.known_grammatical_genders/0`\n  for the list of known grammatical genders. Note that not all locales\n  define all genders.\n\n* `:list_options` is a keyword list of options for formatting a list\n  which is passed through to `Cldr.List.to_string/3`. This is only\n  applicable when formatting a list of units.\n\n* Any other options are passed to `Cldr.Number.to_string/2`\n  which is used to format the `number`","ref":"Cldr.Unit.Format.html#to_iolist!/3-options"},{"type":"function","title":"Returns - Cldr.Unit.Format.to_iolist!/3","doc":"* `io_list` or\n\n* raises an exception","ref":"Cldr.Unit.Format.html#to_iolist!/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.Format.to_iolist!/3","doc":"iex> Cldr.Unit.Format.to_iolist! 123, unit: :gallon\n    [\"123\", \" gallons\"]","ref":"Cldr.Unit.Format.html#to_iolist!/3-examples"},{"type":"function","title":"Cldr.Unit.Format.to_string/1","doc":"Formats a number into a string according to a unit definition\nusing the current process's locale and backend.\n\nSee `Cldr.Unit.to_string/3` for full details.","ref":"Cldr.Unit.Format.html#to_string/1"},{"type":"function","title":"Cldr.Unit.Format.to_string/3","doc":"Formats a unit or unit range or a number into a string according to a unit\ndefinition for a locale.\n\nDuring processing any `:format_options` of a `t:Cldr.Unit.t/0` are merged\ninto the `options` argument.","ref":"Cldr.Unit.Format.html#to_string/3"},{"type":"function","title":"Arguments - Cldr.Unit.Format.to_string/3","doc":"* `list_or_unit` is any number (integer, float or Decimal) or a\n  `t:Cldr.Unit.t/0` struct or a list of `t:Cldr.Unit.t/0` structs or a\n  `t:Cldr.Unit.Range.t/0` struct.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list of options.","ref":"Cldr.Unit.Format.html#to_string/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.Format.to_string/3","doc":"* `:unit` is any unit returned by `Cldr.Unit.known_units/0`. Ignored if\n  the number to be formatted is a `t:Cldr.Unit.t/0` struct.\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`.\n\n* `style` is one of those returned by `Cldr.Unit.known_styles/0`.\n  The current styles are `:long`, `:short` and `:narrow`.\n  The default is `style: :long`.\n\n* `:grammatical_case` indicates that a localisation for the given\n  locale and given grammatical case should be used. See `Cldr.Unit.known_grammatical_cases/0`\n  for the list of known grammatical cases. Note that not all locales\n  define all cases. However all locales do define the `:nominative`\n  case, which is also the default.\n\n* `:gender` indicates that a localisation for the given\n  locale and given grammatical gender should be used.\n  See `Cldr.Unit.known_grammatical_genders/0`\n  for the list of known grammatical genders. Note that not all locales\n  define all genders.\n\n* `:list_options` is a keyword list of options for formatting a list\n  which is passed through to `Cldr.List.to_string/3`. This is only\n  applicable when formatting a list of units.\n\n* Any other options are passed to `Cldr.Number.to_string/2`\n  which is used to format the `number`.","ref":"Cldr.Unit.Format.html#to_string/3-options"},{"type":"function","title":"Returns - Cldr.Unit.Format.to_string/3","doc":"* `{:ok, formatted_string}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Unit.Format.html#to_string/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.Format.to_string/3","doc":"iex> Cldr.Unit.Format.to_string Cldr.Unit.new!(:gallon, 123), MyApp.Cldr\n    {:ok, \"123 gallons\"}\n\n    iex> Cldr.Unit.Format.to_string Cldr.Unit.new!(:gallon, 1), MyApp.Cldr\n    {:ok, \"1 gallon\"}\n\n    iex> Cldr.Unit.Format.to_string Cldr.Unit.new!(:gallon, 1), MyApp.Cldr, locale: \"af\"\n    {:ok, \"1 gelling\"}\n\n    iex> Cldr.Unit.Format.to_string Cldr.Unit.new!(:gallon, 1), MyApp.Cldr, locale: \"bs\"\n    {:ok, \"1 galon\"}\n\n    iex> Cldr.Unit.Format.to_string Cldr.Unit.new!(:gallon, 1234), MyApp.Cldr, format: :long\n    {:ok, \"1 thousand gallons\"}\n\n    iex> Cldr.Unit.Format.to_string Cldr.Unit.new!(:gallon, 1234), MyApp.Cldr, format: :short\n    {:ok, \"1K gallons\"}\n\n    iex> Cldr.Unit.Format.to_string Cldr.Unit.new!(:megahertz, 1234), MyApp.Cldr\n    {:ok, \"1,234 megahertz\"}\n\n    iex> Cldr.Unit.Format.to_string Cldr.Unit.new!(:megahertz, 1234), MyApp.Cldr, style: :narrow\n    {:ok, \"1,234Mhz\"}\n\n    iex> {:ok, range} = Cldr.Unit.Range.new(Cldr.Unit.new!(:gram, 1), Cldr.Unit.new!(:gram, 5))\n    iex> Cldr.Unit.to_string(range, locale: :ja)\n    {:ok, \"1～5 グラム\"}\n\n    iex> Cldr.Unit.Format.to_string Cldr.Unit.new!(123, :foot), MyApp.Cldr\n    {:ok, \"123 feet\"}\n\n    iex> Cldr.Unit.Format.to_string 123, MyApp.Cldr, unit: :foot\n    {:ok, \"123 feet\"}\n\n    iex> Cldr.Unit.Format.to_string Decimal.new(123), MyApp.Cldr, unit: :foot\n    {:ok, \"123 feet\"}\n\n    iex> Cldr.Unit.to_string Cldr.Unit.new!(2, \"curr-usd-per-gallon\"), MyApp.Cldr\n    {:ok, \"$2.00 per gallon\"}\n\n    iex> Cldr.Unit.to_string Cldr.Unit.new!(2, \"gallon-per-curr-usd\"), MyApp.Cldr\n    {:ok, \"2 gallons per US dollar\"}\n\n    iex> Cldr.Unit.Format.to_string 123, MyApp.Cldr, unit: :megabyte, locale: \"en\", style: :unknown\n    {:error, {Cldr.UnknownFormatError, \"The unit style :unknown is not known.\"}}\n\n    iex> Cldr.Unit.Format.to_string 123, MyApp.Cldr, unit: :megabyte, locale: \"en\",\n    ...> grammatical_gender: :feminine\n    {:error, {Cldr.UnknownGrammaticalGenderError,\n      \"The locale :en does not define a grammatical gender :feminine. The valid genders are [:masculine]\"\n    }}","ref":"Cldr.Unit.Format.html#to_string/3-examples"},{"type":"function","title":"Cldr.Unit.Format.to_string!/1","doc":"Formats a unit or unit range or a number into a string according to a unit\ndefinition for the current locale.\n\nDuring processing any `:format_options` of a `t:Cldr.Unit.t/0` are merged\ninto the `options` argument.\n\nThe current process's locale is set with `Cldr.put_locale/1`.\n\nSee `Cldr.Unit.to_string!/3` for full details.","ref":"Cldr.Unit.Format.html#to_string!/1"},{"type":"function","title":"Cldr.Unit.Format.to_string!/3","doc":"Formats a unit or unit range or a number into a string according to a unit\ndefinition for a locale. Raises on error.\n\nDuring processing any `:format_options` of a `t:Cldr.Unit.t/0` are merged\ninto the `options` argument.\n\nDuring processing any `:format_options` of a `t:Cldr.Unit.t/0` are merged with\n`options` with `options` taking precedence.","ref":"Cldr.Unit.Format.html#to_string!/3"},{"type":"function","title":"Arguments - Cldr.Unit.Format.to_string!/3","doc":"* `number_or_unit` is any number (integer, float or Decimal) or a\n  `t:Cldr.Unit.t/0` struct or a list of `t:Cldr.Unit.t/0` structs or a\n  `t:Cldr.Unit.Range.t/0` struct.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list.","ref":"Cldr.Unit.Format.html#to_string!/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.Format.to_string!/3","doc":"* `:unit` is any unit returned by `Cldr.Unit.known_units/0`. Ignored if\n  the number to be formatted is a `t:Cldr.Unit.t/0` struct.\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`.\n\n* `:style` is one of those returned by `Cldr.Unit.available_styles`.\n  The current styles are `:long`, `:short` and `:narrow`.\n  The default is `style: :long`.\n\n* Any other options are passed to `Cldr.Number.to_string/2`\n  which is used to format the `number`.","ref":"Cldr.Unit.Format.html#to_string!/3-options"},{"type":"function","title":"Returns - Cldr.Unit.Format.to_string!/3","doc":"* `formatted_string` or\n\n* raises an exception","ref":"Cldr.Unit.Format.html#to_string!/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.Format.to_string!/3","doc":"iex> Cldr.Unit.Format.to_string! Cldr.Unit.new!(:gallon, 123), MyApp.Cldr\n    \"123 gallons\"\n\n    iex> Cldr.Unit.Format.to_string! Cldr.Unit.new!(:gallon, 1), MyApp.Cldr\n    \"1 gallon\"\n\n    iex> Cldr.Unit.Format.to_string! Cldr.Unit.new!(:gallon, 1), MyApp.Cldr, locale: \"af\"\n    \"1 gelling\"\n\n    iex> {:ok, range} = Cldr.Unit.Range.new(Cldr.Unit.new!(:gram, 1), Cldr.Unit.new!(:gram, 5))\n    iex> Cldr.Unit.to_string!(range, locale: :ja)\n    \"1～5 グラム\"","ref":"Cldr.Unit.Format.html#to_string!/3-examples"},{"type":"function","title":"Cldr.Unit.Format.traverse/2","doc":"Traverses a unit's decomposition and invokes\na function on each node of the composition\ntree.","ref":"Cldr.Unit.Format.html#traverse/2"},{"type":"function","title":"Arguments - Cldr.Unit.Format.traverse/2","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`\n\n* `fun` is any single-arity function. It will be invoked\n  for each node of the composition tree. The argument is a tuple\n  of the following form:\n\n  * `{:unit, argument}`\n  * `{:times, {argument_1, argument_2}}`\n  * `{:prefix, {prefix_unit, argument}}`\n  * `{:power, {power_unit, argument}}`\n  * `{:per, {argument_1, argument_2}}`\n\n  Where the arguments are the results returned\n  from the `fun/1`.","ref":"Cldr.Unit.Format.html#traverse/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Format.traverse/2","doc":"The result returned from `fun/1`","ref":"Cldr.Unit.Format.html#traverse/2-returns"},{"type":"module","title":"Cldr.Unit.Math","doc":"Simple arithmetic functions for the `t.Cldr.Unit.t/0` type.","ref":"Cldr.Unit.Math.html"},{"type":"function","title":"Cldr.Unit.Math.add/2","doc":"Adds two compatible `t:Cldr.Unit.t/0` types","ref":"Cldr.Unit.Math.html#add/2"},{"type":"function","title":"Arguments - Cldr.Unit.Math.add/2","doc":"* `unit_1` and `unit_2` are compatible Units\n  returned by `Cldr.Unit.new/2`.","ref":"Cldr.Unit.Math.html#add/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Math.add/2","doc":"* A `t:Cldr.Unit.t/0` of the same type as `unit_1` with a value\n  that is the sum of `unit_1` and the potentially converted\n  `unit_2`, or\n\n* `{:error, {IncompatibleUnitError, message}}`.","ref":"Cldr.Unit.Math.html#add/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.Math.add/2","doc":"iex> Cldr.Unit.Math.add Cldr.Unit.new!(:foot, 1), Cldr.Unit.new!(:foot, 1)\n    Cldr.Unit.new!(:foot, 2)\n\n    iex> Cldr.Unit.Math.add Cldr.Unit.new!(:foot, 1), Cldr.Unit.new!(:mile, 1)\n    Cldr.Unit.new!(:foot, 5281)\n\n    iex> Cldr.Unit.Math.add Cldr.Unit.new!(:foot, 1), Cldr.Unit.new!(:gallon, 1)\n    {:error, {Cldr.Unit.IncompatibleUnitsError,\n      \"Operations can only be performed between units with the same base unit. Received :foot and :gallon\"}}","ref":"Cldr.Unit.Math.html#add/2-examples"},{"type":"function","title":"Cldr.Unit.Math.add!/2","doc":"Adds two compatible `t:Cldr.Unit.t/0` types\nand raises on error.","ref":"Cldr.Unit.Math.html#add!/2"},{"type":"function","title":"Arguments - Cldr.Unit.Math.add!/2","doc":"* `unit_1` and `unit_2` are compatible Units\n  returned by `Cldr.Unit.new/2`.","ref":"Cldr.Unit.Math.html#add!/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Math.add!/2","doc":"* A `t:Cldr.Unit.t/0` of the same type as `unit_1` with a value\n  that is the sum of `unit_1` and the potentially converted\n  `unit_2` or\n\n* Raises an exception.","ref":"Cldr.Unit.Math.html#add!/2-returns"},{"type":"function","title":"Cldr.Unit.Math.cmp/2","doc":"","ref":"Cldr.Unit.Math.html#cmp/2"},{"type":"function","title":"Cldr.Unit.Math.compare/2","doc":"Compare two units, converting to a common unit\ntype if required.\n\nIf conversion is performed, the results are both\nrounded to a single decimal place before\ncomparison.\n\nReturns `:gt`, `:lt`, or `:eq`.","ref":"Cldr.Unit.Math.html#compare/2"},{"type":"function","title":"Example - Cldr.Unit.Math.compare/2","doc":"iex> x = Cldr.Unit.new!(:kilometer, 1)\n    iex> y = Cldr.Unit.new!(:meter, 1000)\n    iex> Cldr.Unit.Math.compare x, y\n    :eq","ref":"Cldr.Unit.Math.html#compare/2-example"},{"type":"function","title":"Cldr.Unit.Math.div/2","doc":"Divides any `t:Cldr.Unit.t/0` type into another or a\nnumber into a `t:Cldr.Unit.t/0`.","ref":"Cldr.Unit.Math.html#div/2"},{"type":"function","title":"Options - Cldr.Unit.Math.div/2","doc":"* `unit_1` is a unit\n  returned by `Cldr.Unit.new/2`.\n\n* `unit_2` is a unit\n  returned by `Cldr.Unit.new/2` or\n  a number or Decimal.","ref":"Cldr.Unit.Math.html#div/2-options"},{"type":"function","title":"Returns - Cldr.Unit.Math.div/2","doc":"* A `t:Cldr.Unit.t/0` of a type that is the dividend\n  of `unit_1` and `unit_2` with a value\n  that is the dividend of `unit_1` and `unit_2`'s\n  values.","ref":"Cldr.Unit.Math.html#div/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.Math.div/2","doc":"iex> Cldr.Unit.Math.div Cldr.Unit.new!(:kilogram, 5), Cldr.Unit.new!(:pound, 1)\n    Cldr.Unit.new!(:kilogram, \"11.02311310924387903614869007\")\n\n    iex> Cldr.Unit.Math.div Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:liter, 1)\n    Cldr.Unit.new!(:pint, \"2.365882365000000000000000000\")\n\n    iex> Cldr.Unit.Math.div Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:pint, 1)\n    Cldr.Unit.new!(:pint, 5)","ref":"Cldr.Unit.Math.html#div/2-examples"},{"type":"function","title":"Cldr.Unit.Math.div!/2","doc":"Divides one `t:Cldr.Unit.t/0` type into another.\nAny unit can be divided by another.","ref":"Cldr.Unit.Math.html#div!/2"},{"type":"function","title":"Arguments - Cldr.Unit.Math.div!/2","doc":"* `unit_1` is a unit\n  returned by `Cldr.Unit.new/2`.\n\n* `unit_2` is a unit\n  returned by `Cldr.Unit.new/2` or\n  a number or Decimal.","ref":"Cldr.Unit.Math.html#div!/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Math.div!/2","doc":"* A `t:Cldr.Unit.t/0` of the same type as `unit_1` with a value\n  that is the dividend of `unit_1` and the potentially\n  converted `unit_2` or\n\n* Raises an exception.","ref":"Cldr.Unit.Math.html#div!/2-returns"},{"type":"function","title":"Cldr.Unit.Math.mult/2","doc":"Multiplies any two `t:Cldr.Unit.t/0` types or a t:Cldr.Unit.t/0`\nand a scalar.","ref":"Cldr.Unit.Math.html#mult/2"},{"type":"function","title":"Arguments - Cldr.Unit.Math.mult/2","doc":"* `unit_1` is a unit\n  returned by `Cldr.Unit.new/2`.\n\n* `unit_2` is a unit\n  returned by `Cldr.Unit.new/2` or\n  a number or Decimal.","ref":"Cldr.Unit.Math.html#mult/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Math.mult/2","doc":"* A `t:Cldr.Unit.t/0` of a type that is the product\n  of `unit_1` and `unit_2` with a value\n  that is the product of `unit_1` and `unit_2`'s\n  values.","ref":"Cldr.Unit.Math.html#mult/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.Math.mult/2","doc":"iex> Cldr.Unit.mult Cldr.Unit.new!(:kilogram, 5), Cldr.Unit.new!(:pound, 1)\n    Cldr.Unit.new!(:kilogram, \"2.26796185\")\n\n    iex> Cldr.Unit.mult Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:liter, 1)\n    Cldr.Unit.new!(:pint, \"10.56688209432593661519599687\")\n\n    iex> Cldr.Unit.mult Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:pint, 1)\n    Cldr.Unit.new!(:pint, 5)","ref":"Cldr.Unit.Math.html#mult/2-examples"},{"type":"function","title":"Cldr.Unit.Math.mult!/2","doc":"Multiplies two compatible `t:Cldr.Unit.t/0` types\nand raises on error.","ref":"Cldr.Unit.Math.html#mult!/2"},{"type":"function","title":"Options - Cldr.Unit.Math.mult!/2","doc":"* `unit_1` is a unit\n  returned by `Cldr.Unit.new/2`.\n\n* `unit_2` is a unit\n  returned by `Cldr.Unit.new/2` or\n  a number or Decimal.","ref":"Cldr.Unit.Math.html#mult!/2-options"},{"type":"function","title":"Returns - Cldr.Unit.Math.mult!/2","doc":"* A `t:Cldr.Unit.t/0` of the same type as `unit_1` with a value\n  that is the product of `unit_1` and the potentially\n  converted `unit_2` or\n\n* Raises an exception.","ref":"Cldr.Unit.Math.html#mult!/2-returns"},{"type":"function","title":"Cldr.Unit.Math.round/3","doc":"Rounds the value of a unit.","ref":"Cldr.Unit.Math.html#round/3"},{"type":"function","title":"Arguments - Cldr.Unit.Math.round/3","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`\n\n* `places` is the number of decimal places to round to.\n  The default is `0`.\n\n* `mode` is the rounding mode to be applied.  The default\n  is `:half_up`.","ref":"Cldr.Unit.Math.html#round/3-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Math.round/3","doc":"* A `%Unit{}` of the same type as `unit` with a value\n  that is rounded to the specified number of decimal places.","ref":"Cldr.Unit.Math.html#round/3-returns"},{"type":"function","title":"Rounding modes - Cldr.Unit.Math.round/3","doc":"Directed roundings:\n\n* `:down` - Round towards 0 (truncate), eg 10.9 rounds to 10.0\n\n* `:up` - Round away from 0, eg 10.1 rounds to 11.0. (Non IEEE algorithm)\n\n* `:ceiling` - Round toward +∞ - Also known as rounding up or ceiling\n\n* `:floor` - Round toward -∞ - Also known as rounding down or floor\n\nRound to nearest:\n\n* `:half_even` - Round to nearest value, but in a tiebreak, round towards the\n  nearest value with an even (zero) least significant bit, which occurs 50%\n  of the time. This is the default for IEEE binary floating-point and the recommended\n  value for decimal.\n\n* `:half_up` - Round to nearest value, but in a tiebreak, round away from 0.\n  This is the default algorithm for Erlang's Kernel.round/2\n\n* `:half_down` - Round to nearest value, but in a tiebreak, round towards 0\n  (Non IEEE algorithm)","ref":"Cldr.Unit.Math.html#round/3-rounding-modes"},{"type":"function","title":"Examples - Cldr.Unit.Math.round/3","doc":"iex> Cldr.Unit.round Cldr.Unit.new!(:yard, 1031.61), 1\n    Cldr.Unit.new!(:yard, \"1031.6\")\n\n    iex> Cldr.Unit.round Cldr.Unit.new!(:yard, 1031.61), 2\n    Cldr.Unit.new!(:yard, \"1031.61\")\n\n    iex> Cldr.Unit.round Cldr.Unit.new!(:yard, 1031.61), 1, :up\n    Cldr.Unit.new!(:yard, \"1031.7\")","ref":"Cldr.Unit.Math.html#round/3-examples"},{"type":"function","title":"Cldr.Unit.Math.sub/2","doc":"Subtracts two compatible `t:Cldr.Unit.t/0` types.","ref":"Cldr.Unit.Math.html#sub/2"},{"type":"function","title":"Arguments - Cldr.Unit.Math.sub/2","doc":"* `unit_1` and `unit_2` are compatible Units\n  returned by `Cldr.Unit.new/2`.","ref":"Cldr.Unit.Math.html#sub/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Math.sub/2","doc":"* A `t:Cldr.Unit.t/0` of the same type as `unit_1` with a value\n  that is the difference between `unit_1` and the potentially\n  converted `unit_2`, or\n\n* `{:error, {IncompatibleUnitError, message}}`.","ref":"Cldr.Unit.Math.html#sub/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.Math.sub/2","doc":"iex> Cldr.Unit.sub Cldr.Unit.new!(:kilogram, 5), Cldr.Unit.new!(:pound, 1)\n    Cldr.Unit.new!(:kilogram, \"4.54640763\")\n\n    iex> Cldr.Unit.sub Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:liter, 1)\n    Cldr.Unit.new!(:pint, \"2.886623581134812676960800627\")\n\n    iex> Cldr.Unit.sub Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:pint, 1)\n    Cldr.Unit.new!(:pint, 4)","ref":"Cldr.Unit.Math.html#sub/2-examples"},{"type":"function","title":"Cldr.Unit.Math.sub!/2","doc":"Subtracts two compatible `t:Cldr.Unit.t/0` types\nand raises on error.","ref":"Cldr.Unit.Math.html#sub!/2"},{"type":"function","title":"Arguments - Cldr.Unit.Math.sub!/2","doc":"* `unit_1` and `unit_2` are compatible Units\n  returned by `Cldr.Unit.new/2`.","ref":"Cldr.Unit.Math.html#sub!/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Math.sub!/2","doc":"* A `t:Cldr.Unit.t/0` of the same type as `unit_1` with a value\n  that is the difference between `unit_1` and the potentially\n  converted `unit_2` or\n\n* Raises an exception.","ref":"Cldr.Unit.Math.html#sub!/2-returns"},{"type":"function","title":"Cldr.Unit.Math.trunc/1","doc":"Truncates a unit's value.","ref":"Cldr.Unit.Math.html#trunc/1"},{"type":"type","title":"Cldr.Unit.Math.rounding_mode/0","doc":"","ref":"Cldr.Unit.Math.html#t:rounding_mode/0"},{"type":"module","title":"Cldr.Unit.Parser","doc":"Parse unit strings into composable\nunit structures.  These structures can\nthen be used to produced localized output,\nor to be converted to another unit of the\nsame unit category.","ref":"Cldr.Unit.Parser.html"},{"type":"function","title":"Cldr.Unit.Parser.canonical_unit_name/1","doc":"Returns the canonical unit name\nfor a unit","ref":"Cldr.Unit.Parser.html#canonical_unit_name/1"},{"type":"function","title":"Arguments - Cldr.Unit.Parser.canonical_unit_name/1","doc":"* `unit_string` is any string representing\n  a unit such as `light_year_per_week`.","ref":"Cldr.Unit.Parser.html#canonical_unit_name/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Parser.canonical_unit_name/1","doc":"* `{:ok, canonical_name}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.Parser.html#canonical_unit_name/1-returns"},{"type":"function","title":"Examples - Cldr.Unit.Parser.canonical_unit_name/1","doc":"iex> Cldr.Unit.Parser.canonical_unit_name \"meter\"\n    {:ok, :meter}\n\n    iex> Cldr.Unit.Parser.canonical_unit_name \"meter meter\"\n    {:ok, :square_meter}\n\n    iex> Cldr.Unit.Parser.canonical_unit_name \"meter per kilogram\"\n    {:ok, \"meter_per_kilogram\"}\n\n    iex> Cldr.Unit.Parser.canonical_unit_name \"meter kilogram\"\n    {:ok, \"kilogram_meter\"}\n\n    iex> Cldr.Unit.Parser.canonical_unit_name \"meter kilogram per fluxom\"\n    {:error, {Cldr.UnknownUnitError, \"Unknown unit was detected at \\\"fluxom\\\"\"}}","ref":"Cldr.Unit.Parser.html#canonical_unit_name/1-examples"},{"type":"function","title":"Cldr.Unit.Parser.canonical_unit_name!/1","doc":"Returns the canonical unit name\nfor a unit or raises on error","ref":"Cldr.Unit.Parser.html#canonical_unit_name!/1"},{"type":"function","title":"Arguments - Cldr.Unit.Parser.canonical_unit_name!/1","doc":"* `unit_string` is any string representing\n  a unit such as `light_year_per_week`.","ref":"Cldr.Unit.Parser.html#canonical_unit_name!/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Parser.canonical_unit_name!/1","doc":"* `{:ok, canonical_name}` or\n\n* raises an exception","ref":"Cldr.Unit.Parser.html#canonical_unit_name!/1-returns"},{"type":"function","title":"Examples - Cldr.Unit.Parser.canonical_unit_name!/1","doc":"iex> Cldr.Unit.Parser.canonical_unit_name! \"meter\"\n    :meter\n\n    iex> Cldr.Unit.Parser.canonical_unit_name! \"meter meter\"\n    :square_meter\n\n    iex> Cldr.Unit.Parser.canonical_unit_name! \"meter per kilogram\"\n    \"meter_per_kilogram\"\n\n    iex> Cldr.Unit.Parser.canonical_unit_name! \"meter kilogram\"\n    \"kilogram_meter\"\n\n    iex> Cldr.Unit.Parser.canonical_unit_name \"curr-usd\"\n    {:ok, \"curr_usd\"}\n\n    iex> Cldr.Unit.Parser.canonical_unit_name \"curr-usd-per-kilogram\"\n    {:ok, \"curr_usd_per_kilogram\"}\n\n    => Cldr.Unit.Parser.canonical_unit_name! \"meter kilogram per fluxom\"\n    ** (CaseClauseError) no case clause matching: {:error,\n        {Cldr.UnknownUnitError, \"Unknown unit was detected at \"fluxom\"\"}}","ref":"Cldr.Unit.Parser.html#canonical_unit_name!/1-examples"},{"type":"function","title":"Cldr.Unit.Parser.parse_unit/1","doc":"Parses a unit name expressed as a string and returns the parsed\nname or an error.","ref":"Cldr.Unit.Parser.html#parse_unit/1"},{"type":"function","title":"Arguments - Cldr.Unit.Parser.parse_unit/1","doc":"* `unit_string` is a unit name (such as\n  \"meter\") as a `String.t()`","ref":"Cldr.Unit.Parser.html#parse_unit/1-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Parser.parse_unit/1","doc":"* `{:ok, normalized_unit}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.Parser.html#parse_unit/1-returns"},{"type":"function","title":"Notes - Cldr.Unit.Parser.parse_unit/1","doc":"A normalised unit is a `2-tuple` with\nthe first element a list of standard units\nthat are before the first \"per\" in the\nunit name.  The second element is a list\nof standard units after the first \"per\"\n(if any).\n\nThe structure of the standard unit is\n`{standard_unit, conversion_to_base_unit}`.\n\nThis function is not normally called by\nconsumers of this library. It is called by\n`Cldr.Unit.validate_unit/1` which is the\nmain public API.","ref":"Cldr.Unit.Parser.html#parse_unit/1-notes"},{"type":"function","title":"Example - Cldr.Unit.Parser.parse_unit/1","doc":"iex> Cldr.Unit.Parser.parse_unit \"kilogram per light year\"\n    {:ok,\n     {[\n        {:kilogram,\n         %Cldr.Unit.Conversion{\n           base_unit: [:kilogram],\n           factor: 1,\n           offset: 0\n         }}\n      ],\n      [\n        {:light_year,\n         %Cldr.Unit.Conversion{\n           base_unit: [:meter],\n           factor: 9460730472580800,\n           offset: 0\n         }}\n      ]}}","ref":"Cldr.Unit.Parser.html#parse_unit/1-example"},{"type":"function","title":"Cldr.Unit.Parser.parse_unit!/1","doc":"","ref":"Cldr.Unit.Parser.html#parse_unit!/1"},{"type":"function","title":"Cldr.Unit.Parser.split_into_units/1","doc":"","ref":"Cldr.Unit.Parser.html#split_into_units/1"},{"type":"module","title":"Cldr.Unit.Preference","doc":"In many cultures, the common unit of measure for some\nunit categories varies based upon the usage of the\nunit.\n\nFor example, when describing unit length in the US, the\ncommon use units vary based upon usage such as:\n\n* road distance (miles for larger distances, feet for smaller)\n* person height (feet and inches)\n* snowfall (inches)\n\nThis module provides functions to introspect CLDRs\npreference data for difference use cases in different\nlocales.","ref":"Cldr.Unit.Preference.html"},{"type":"function","title":"Cldr.Unit.Preference.debug/5","doc":"","ref":"Cldr.Unit.Preference.html#debug/5"},{"type":"function","title":"Cldr.Unit.Preference.preferred_units/3","doc":"Returns a list of the preferred units for a given\nunit, locale, territory and use case.\n\nThe units used to represent length, volume and so on\ndepend on a given territory, measurement system and usage.\n\nFor example, in the US, people height is most commonly\nreferred to in `inches`, or informally as `feet and inches`.\nIn most of the rest of the world it is `centimeters`.","ref":"Cldr.Unit.Preference.html#preferred_units/3"},{"type":"function","title":"Arguments - Cldr.Unit.Preference.preferred_units/3","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`.\n\n* `backend` is any Cldr backend module. That is, any module\n  that includes `use Cldr`. The default is `Cldr.default_backend!/0`\n\n* `options` is a keyword list of options or a\n  `t:Cldr.Unit.Conversion.Options` struct. The default\n  is `[]`.","ref":"Cldr.Unit.Preference.html#preferred_units/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.Preference.preferred_units/3","doc":"* `:usage` is the unit usage. for example `;person` for a unit\n  of type `:length`. The available usage for a given unit category can\n  be seen with `Cldr.Unit.unit_category_usage/0`. The default is `nil`.\n\n* `:scope` is either `:small` or `nil`. In some usage, the units\n  used are different when the unit size is small. It is up to the\n  developer to determine when `scope: :small` is appropriate.\n\n* `:alt` is either `:informal` or `nil`. Like `:scope`, the units\n  in use depend on whether they are being used in a formal or informal\n  context.\n\n* `:locale` is any locale returned by `Cldr.validate_locale/2`","ref":"Cldr.Unit.Preference.html#preferred_units/3-options"},{"type":"function","title":"Returns - Cldr.Unit.Preference.preferred_units/3","doc":"* `{:ok, unit_list}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Unit.Preference.html#preferred_units/3-returns"},{"type":"function","title":"Examples - Cldr.Unit.Preference.preferred_units/3","doc":"iex> meter = Cldr.Unit.new!(:meter, 1)\n    iex> many_meters = Cldr.Unit.new!(:meter, 10_000)\n    iex> Cldr.Unit.Preference.preferred_units meter, MyApp.Cldr, locale: \"en-US\", usage: :person\n    {:ok, [:inch], []}\n    iex> Cldr.Unit.Preference.preferred_units meter, MyApp.Cldr, locale: \"en-AU\", usage: :person\n    {:ok, [:centimeter], []}\n    iex> Cldr.Unit.Preference.preferred_units meter, MyApp.Cldr, locale: \"en-US\", usage: :road\n    {:ok, [:foot], [round_nearest: 1]}\n    iex> Cldr.Unit.Preference.preferred_units many_meters, MyApp.Cldr, locale: \"en-US\", usage: :road\n    {:ok, [:mile], []}\n    iex> Cldr.Unit.Preference.preferred_units meter, MyApp.Cldr, locale: \"en-AU\", usage: :road\n    {:ok, [:meter], [round_nearest: 1]}\n    iex> Cldr.Unit.Preference.preferred_units many_meters, MyApp.Cldr, locale: \"en-AU\", usage: :road\n    {:ok, [:kilometer], []}","ref":"Cldr.Unit.Preference.html#preferred_units/3-examples"},{"type":"function","title":"Notes - Cldr.Unit.Preference.preferred_units/3","doc":"One common pattern is to convert a given unit into the unit\nappropriate for a given locale and usage. This can be\naccomplished with a combination of `Cldr.Unit.Preference.preferred_units/3`\nand `Cldr.Unit.decompose/2`. For example:\n\n    iex> meter = Cldr.Unit.new!(:meter, 1)\n    iex> preferred_units = Cldr.Unit.Preference.preferred_units(meter,\n    ...>   MyApp.Cldr, locale: \"en-US\", usage: :person)\n    iex> with {:ok, preferred_units, _} <- preferred_units do\n    ...>   Cldr.Unit.decompose(meter, preferred_units)\n    ...> end\n    [Cldr.Unit.new!(:inch, \"39.37007874015748031496062992\")]","ref":"Cldr.Unit.Preference.html#preferred_units/3-notes"},{"type":"function","title":"Cldr.Unit.Preference.preferred_units/4","doc":"","ref":"Cldr.Unit.Preference.html#preferred_units/4"},{"type":"function","title":"Cldr.Unit.Preference.preferred_units!/3","doc":"Returns a list of the preferred units for a given\nunit, locale, territory and use case.\n\nThe units used to represent length, volume and so on\ndepend on a given territory, measurement system and usage.\n\nFor example, in the US, people height is most commonly\nreferred to in `inches`, or `feet and inches`.\nIn most of the rest of the world it is `centimeters`.","ref":"Cldr.Unit.Preference.html#preferred_units!/3"},{"type":"function","title":"Arguments - Cldr.Unit.Preference.preferred_units!/3","doc":"* `unit` is any unit returned by `Cldr.Unit.new/2`.\n\n* `backend` is any Cldr backend module. That is, any module\n  that includes `use Cldr`. The default is `Cldr.default_backend!/0`\n\n* `options` is a keyword list of options or a\n  `t:Cldr.Unit.Conversion.Options` struct. The default\n  is `[]`.","ref":"Cldr.Unit.Preference.html#preferred_units!/3-arguments"},{"type":"function","title":"Options - Cldr.Unit.Preference.preferred_units!/3","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `backend.get_locale/0`\n\n* `:territory` is any valid territory code returned by\n  `Cldr.known_territories/0`. The default is the territory defined\n  as part of the `:locale`. The option `:territory` has a precedence\n  over the territory in a locale.\n\n* `:usage` is the way in which the unit is intended\n  to be used.  The available `usage` varyies according\n  to the unit category.  See `Cldr.Unit.unit_category_usage/0`.","ref":"Cldr.Unit.Preference.html#preferred_units!/3-options"},{"type":"function","title":"Returns - Cldr.Unit.Preference.preferred_units!/3","doc":"* `unit_list` or\n\n* raises an exception","ref":"Cldr.Unit.Preference.html#preferred_units!/3-returns"},{"type":"function","title":"Note - Cldr.Unit.Preference.preferred_units!/3","doc":"This function, unlike `Cldr.Unit.preferred_units/3` does not\nreturn any available formatting hints.","ref":"Cldr.Unit.Preference.html#preferred_units!/3-note"},{"type":"function","title":"Examples - Cldr.Unit.Preference.preferred_units!/3","doc":"iex> meter = Cldr.Unit.new!(:meter, 1)\n    iex> Cldr.Unit.Preference.preferred_units! meter, MyApp.Cldr, locale: \"en-US\", usage: :person_height\n    [:foot, :inch]\n    iex> Cldr.Unit.Preference.preferred_units! meter, MyApp.Cldr, locale: \"en-US\", usage: :person\n    [:inch]\n    iex> Cldr.Unit.Preference.preferred_units! meter, MyApp.Cldr, locale: \"en-AU\", usage: :person\n    [:centimeter]\n    iex> Cldr.Unit.Preference.preferred_units! meter, MyApp.Cldr, locale: \"en-US\", usage: :road\n    [:foot]\n    iex> Cldr.Unit.Preference.preferred_units! meter, MyApp.Cldr, locale: \"en-AU\", usage: :road\n    [:meter]","ref":"Cldr.Unit.Preference.html#preferred_units!/3-examples"},{"type":"function","title":"Cldr.Unit.Preference.unknown_preferences_error/4","doc":"","ref":"Cldr.Unit.Preference.html#unknown_preferences_error/4"},{"type":"function","title":"Cldr.Unit.Preference.unknown_usage_error/2","doc":"","ref":"Cldr.Unit.Preference.html#unknown_usage_error/2"},{"type":"function","title":"Cldr.Unit.Preference.validate_usage/2","doc":"","ref":"Cldr.Unit.Preference.html#validate_usage/2"},{"type":"module","title":"Cldr.Unit.Range","doc":"Implements a unit range type, similar to `Date.Range`.\n\nA unit range but be comprise `first` and `last` units that\nhave the same base unit. The `last` unit will be converted\nto the unit type of the `first` unit.\n\nUnit ranges are useful in at least the following cases:\n\n1. To be able to enumerate a unit range.\n2. To be able to format a unit range in a localised manner using\n  `Cldr.Number.to_range_string/2`.","ref":"Cldr.Unit.Range.html"},{"type":"function","title":"Cldr.Unit.Range.new/2","doc":"Returns a new Cldr.Unit.Range.","ref":"Cldr.Unit.Range.html#new/2"},{"type":"function","title":"Arguments - Cldr.Unit.Range.new/2","doc":"* `first` is any `t:Cldr.Unit.t/0` returned by `Cldr.Unit.new/2`.\n\n* `last` is any `t:Cldr.Unit.t/0` returned by `Cldr.Unit.new/2`\n  that is convertible to the same unit as `first` and where its\n  converted value is greater than or equal to the value of `first`.","ref":"Cldr.Unit.Range.html#new/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Range.new/2","doc":"* `{:ok, unit_range}` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Unit.Range.html#new/2-returns"},{"type":"function","title":"Examples - Cldr.Unit.Range.new/2","doc":"iex> Cldr.Unit.Range.new Cldr.Unit.new!(:gram, 1), Cldr.Unit.new!(:gram, 4)\n    {:ok, Cldr.Unit.Range.new!(Cldr.Unit.new!(:gram, 1), Cldr.Unit.new!(:gram, 4))}\n\n    iex> Cldr.Unit.Range.new Cldr.Unit.new!(:gram, 1), Cldr.Unit.new!(:liter, 4)\n    {:error,\n     {Cldr.Unit.InvalidRangeError,\n      \"Unit ranges require that the last unit can be converted to the first unit. \" <>\n      \"Found Cldr.Unit.new!(:gram, 1) and Cldr.Unit.new!(:liter, 4)\"}}\n\n    iex> Cldr.Unit.Range.new Cldr.Unit.new!(:gram, 5), Cldr.Unit.new!(:gram, 4)\n    {:error,\n     {Cldr.Unit.InvalidRangeError,\n      \"Unit ranges require that the first unit be less than or equal to the last. \" <>\n      \"Found Cldr.Unit.new!(:gram, 5) and Cldr.Unit.new!(:gram, 4)\"}}","ref":"Cldr.Unit.Range.html#new/2-examples"},{"type":"function","title":"Cldr.Unit.Range.new!/2","doc":"Returns a new Cldr.Unit.Range or raises an exception.","ref":"Cldr.Unit.Range.html#new!/2"},{"type":"function","title":"Arguments - Cldr.Unit.Range.new!/2","doc":"* `first` is any `t:Cldr.Unit.t/0` returned by `Cldr.Unit.new/2`.\n\n* `last` is any `t:Cldr.Unit.t/0` returned by `Cldr.Unit.new/2`\n  that is convertible to the same unit as `first` and where its\n  converted value is greater than or equal to the value of `first`.","ref":"Cldr.Unit.Range.html#new!/2-arguments"},{"type":"function","title":"Returns - Cldr.Unit.Range.new!/2","doc":"* `unit_range` or\n\n* raises an exception.","ref":"Cldr.Unit.Range.html#new!/2-returns"},{"type":"function","title":"Example - Cldr.Unit.Range.new!/2","doc":"iex> Cldr.Unit.Range.new! Cldr.Unit.new!(:gram, 1), Cldr.Unit.new!(:gram, 4)\n    Cldr.Unit.Range.new!(Cldr.Unit.new!(:gram, 1), Cldr.Unit.new!(:gram, 4))","ref":"Cldr.Unit.Range.html#new!/2-example"},{"type":"function","title":"Cldr.Unit.Range.to_iolist/1","doc":"","ref":"Cldr.Unit.Range.html#to_iolist/1"},{"type":"function","title":"Cldr.Unit.Range.to_iolist/2","doc":"","ref":"Cldr.Unit.Range.html#to_iolist/2"},{"type":"function","title":"Cldr.Unit.Range.to_iolist/3","doc":"","ref":"Cldr.Unit.Range.html#to_iolist/3"},{"type":"function","title":"Cldr.Unit.Range.to_string/1","doc":"","ref":"Cldr.Unit.Range.html#to_string/1"},{"type":"function","title":"Cldr.Unit.Range.to_string/2","doc":"","ref":"Cldr.Unit.Range.html#to_string/2"},{"type":"function","title":"Cldr.Unit.Range.to_string/3","doc":"","ref":"Cldr.Unit.Range.html#to_string/3"},{"type":"type","title":"Cldr.Unit.Range.t/0","doc":"A unit range consists of two units where the\nlast unit can be converted to the same unit type\nas the first unit.","ref":"Cldr.Unit.Range.html#t:t/0"},{"type":"extras","title":"Cldr for Units","doc":"# Cldr for Units\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_cldr_units.svg)](https://hex.pm/packages/ex_cldr_units)\n[![Hex.pm](https://img.shields.io/hexpm/dw/ex_cldr_units.svg?)](https://hex.pm/packages/ex_cldr_units)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_cldr_units.svg)](https://hex.pm/packages/ex_cldr_units)","ref":"readme.html"},{"type":"extras","title":"Installation - Cldr for Units","doc":"Note that `:ex_cldr_units` requires Elixir 1.6 or later.\n\nAdd `ex_cldr_units` as a dependency to your `mix` project:\n\n    defp deps do\n      [\n        {:ex_cldr_units, \"~> 3.0\"}\n      ]\n    end\n\nthen retrieve `ex_cldr_units` from [hex](https://hex.pm/packages/ex_cldr_units):\n\n    mix deps.get\n    mix deps.compile\n\nDocumentation can be found at [https://hexdocs.pm/ex_cldr_units](https://hexdocs.pm/ex_cldr_units).","ref":"readme.html#installation"},{"type":"extras","title":"Getting Started - Cldr for Units","doc":"`ex_cldr_units` is an add-on library for [ex_cldr](https://hex.pm/packages/ex_cldr) that provides localisation and formatting for units such as weights, lengths, areas, volumes and so on. It also provides unit conversion and simple arithmetic for compatible units.","ref":"readme.html#getting-started"},{"type":"extras","title":"Configuration - Cldr for Units","doc":"From [ex_cldr](https://hex.pm/packages/ex_cldr) version 2.0, a backend module must be defined into which the public API and the [CLDR](https://cldr.unicode.org) data is compiled.  See the [ex_cldr documentation](https://hexdocs.pm/ex_cldr/readme.html) for further information on configuration.\n\nIn the following examples we assume the presence of a module called `MyApp.Cldr` defined as:\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"fr\"],\n    default_locale: \"en\",\n    providers: [Cldr.Number, Cldr.Unit, Cldr.List]\nend\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Supporting the String.Chars protocol - Cldr for Units","doc":"The `String.Chars` protocol underpins `Kernel.to_string/1` and is also used in string interpolation such as `#{my_unit}`.  In order for this to be supported by `Cldr.Unit`, a default backend module must be configured in `config.exs`.  For example:\n```\nconfig :ex_cldr_units,\n  default_backend: MyApp.Cldr\n```","ref":"readme.html#supporting-the-string-chars-protocol"},{"type":"extras","title":"Public API - Cldr for Units","doc":"The primary api is defined by three functions:\n\n* `MyApp.Cldr.Unit.to_string/2` for formatting units\n\n* `MyApp.Cldr.Unit.new/2` to create a new `Unit.t` struct that encapsulated a unit and a value that can be used for arithmetic, comparison and conversion\n\n* `MyApp.Cldr.Unit.convert/2` to convert one compatible unit to another\n\n* `MyApp.Cldr.Unit.localize/3` to localize a unit by converting it to units customary for a given territory\n\n* `MyApp.Cldr.Unit.add/2`, `MyApp.Cldr.Unit.sub/2`, `MyApp.Cldr.Unit.mult/2`, `MyApp.Cldr.Unit.div/2` provide basic arithmetic operations on compatible `Unit.t` structs.","ref":"readme.html#public-api"},{"type":"extras","title":"Creating a new unit - Cldr for Units","doc":"A `Cldr.Unit.t()` struct is created with the `Cldr.Unit.new/2` function. The two parameters are a unit name and a number (expressed as a `float`, `integer`, `Decimal` or `Ratio`) in either order.\n\nNaming units is quite flexible combining:\n\n* One or more base unit names. These are the names returned from `Cldr.Unit.known_units/0`\n\n* An optional SI prefix (from `yokto` to `yotta`)\n\n* An optional power prefix of `square` or `cubic`\n\nNames can be expressed as strings with any of `-`, `_` or ` ` as separators between words.\n\nSome examples:\n\n```elixir\niex> Cldr.Unit.new :meter, 1\n{:ok, #Cldr.Unit<:meter, 1>}\n\niex> Cldr.Unit.new \"square meter\", 1\n{:ok, #Cldr.Unit<:square_meter, 1>}\n\niex> Cldr.Unit.new \"square liter\", 1\n{:ok, #Cldr.Unit<\"square_liter\", 1>}\n\niex> Cldr.Unit.new \"square yottaliter\", 1\n{:ok, #Cldr.Unit<\"square_yottaliter\", 1>}\n\niex> Cldr.Unit.new \"cubic light year\", 1\n{:ok, #Cldr.Unit<\"cubic_light_year\", 1>}\n\niex> Cldr.Unit.new \"squre meter\", 1\n{:error,\n {Cldr.UnknownUnitError, \"Unknown unit was detected at \\\"squre_meter\\\"\"}}\n```\n\nYou will note that the unit make not make logical sense (`cubic light-year`?) but they do make mathematical sense.\n\nUnits can also be described as the product of one or more base units. For example:\n\n```elixir\niex> Cldr.Unit.new \"liter ampere\", 1\n{:ok, #Cldr.Unit<\"ampere_liter\", 1>}\n\niex> Cldr.Unit.new \"mile lux\", 1\n{:ok, #Cldr.Unit<\"mile_lux\", 1>}\n```\n\nAgain, this may not have a logical meaning but they do have an arithmetic meaning and they can be formatted as strings:\n\n```elixir\niex> Cldr.Unit.new!(\"liter ampere\", 1) |> Cldr.Unit.to_string\n{:ok, \"1 ampere⋅litre\"}\n\niex> Cldr.Unit.new!(\"mile lux\", 3) |> Cldr.Unit.to_string\n{:ok, \"3 miles⋅lux\"}\n```\n\nLastly, there are units formed by division where are called \"per\" units. For example:\n\n```elixir\niex> Cldr.Unit.new \"mile per hour\", 1\n{:ok, #Cldr.Unit<:mile_per_hour, 1>}\n\niex> Cldr.Unit.new \"liter per second\", 1\n{:ok, #Cldr.Unit<\"liter_per_second\", 1>}\n\niex> Cldr.Unit.new \"cubic gigalux per inch\", 1\n{:ok, #Cldr.Unit<\"cubic_gigalux_per_inch\", 1>}\n```","ref":"readme.html#creating-a-new-unit"},{"type":"extras","title":"Unit formatting and localization - Cldr for Units","doc":"`MyApp.Cldr.Unit.to_string/2` provides localized unit formatting. It supports two arguments:\n\n  * `number` is any number (integer, float or Decimal) or a `Unit.t` struct returned by `Cldr.Unit.new/2`\n\n  * `options` which are:\n\n    * `:unit` is any unit returned by `Cldr.Unit.known_units/0`.  This option is required unless a `Unit.t` is passed as the first argument.\n\n    * `:locale` is any configured locale. See `Cldr.known_locale_names/0`. The default\n      is `locale: Cldr.get_current_locale()`\n\n    * `:style` is one of those returned by `Cldr.Unit.available_styles`.\n      The current styles are `:long`, `:short` and `:narrow`.  The default is `style: :long`\n\n    * Any other options are passed to `Cldr.Number.to_string/2` which is used to format the `number`\n\n```elixir\niex> MyApp.Cldr.Unit.to_string 123, unit: :gallon\n{:ok, \"123 gallons\"}\n\niex> MyApp.Cldr.Unit.to_string 1234, unit: :gallon, format: :long\n{:ok, \"1 thousand gallons\"}\n\niex> MyApp.Cldr.Unit.to_string 1234, unit: :gallon, format: :short\n{:ok, \"1K gallons\"}\n\niex> MyApp.Cldr.Unit.to_string 1234, unit: :megahertz\n{:ok, \"1,234 megahertz\"}\n\niex> MyApp.Cldr.Unit.to_string 1234, unit: :foot, locale: \"fr\"\n{:ok, \"1 234 pieds\"}\n\niex> MyApp.Cldr.Unit.to_string Cldr.Unit.new(:ampere, 42), locale: \"fr\"\n{:ok, \"42 ampères\"}\n\niex> Cldr.Unit.to_string 1234, MyApp.Cldr, unit: \"foot_per_second\", style: :narrow, per: :second\n{:ok, \"1,234′/s\"}\n\niex> Cldr.Unit.to_string 1234, MyApp.Cldr, unit: \"foot_per_second\"\n{:ok, \"1,234 feet per second\"}\n\n```","ref":"readme.html#unit-formatting-and-localization"},{"type":"extras","title":"Unit decomposition - Cldr for Units","doc":"Sometimes its a requirement to decompose a unit into one or more subunits.  For example, if someone is 6.3 feet height we would normally say \"6 feet, 4 inches\".  This can be achieved with `Cldr.Unit.decompose/2`. Using our example:\n\n```elixir\niex> height = Cldr.Unit.new(:foot, 6.3)\n#Cldr.Unit<:foot, 6.3>\niex(2)> Cldr.Unit.decompose height, [:foot, :inch]\n[#Cldr.Unit<:foot, 6.0>, #Cldr.Unit<:inch, 4.0>]\n```\n\nA localised string representing this decomposition can also be produced.  `Cldr.Unit.to_string/3` will process a unit list, using the function `Cldr.List.to_string/2` to perform the list combination.  Again using the example:\n\n```elixir\niex> c = Cldr.Unit.decompose height, [:foot, :inch]\n[#Cldr.Unit<:foot, 6.0>, #Cldr.Unit<:inch, 4.0>]\n\niex> Cldr.Unit.to_string c, MyApp.Cldr\n\"6 feet and 4 inches\"\n\niex> Cldr.Unit.to_string c, MyApp.Cldr, list_options: [format: :unit_short]\n\"6 feet, 4 inches\"\n# And of course full localisation is supported\niex> Cldr.Unit.to_string c, MyApp.Cldr, locale: \"fr\"\n\"6 pieds et 4 pouces\"\n```","ref":"readme.html#unit-decomposition"},{"type":"extras","title":"Converting Units - Cldr for Units","doc":"`t:Unit` structs can be converted to other compatible units.  For example, `feet` can be converted to `meters` since they are both of the `length` unit type.\n\n```elixir\n# Test for unit compatibility\niex> Cldr.Unit.compatible? :foot, :meter\ntrue\niex> Cldr.Unit.compatible? :foot, :liter\nfalse\n\n# Convert a unit\niex> Cldr.Unit.convert Cldr.Unit.new!(:foot, 3), :meter\n{:ok, #Cldr.Unit<:meter, 16472365997070327 <|> 18014398509481984>}\n\n```","ref":"readme.html#converting-units"},{"type":"extras","title":"Localising units for a given locale or territory - Cldr for Units","doc":"Different locales or territories use different measurement systems and sometimes different measurement scales that also vary based upon usage. For example, in the US a person's height is considered in `inches` up to a certain point and `feet and inches` after that. For distances when driving, the length is considered in `yards` for certain distances and `miles` after that. For most other countries the same quantity would be expressed in `centimeters` or `meters` or `kilometers`.\n\n`ex_cldr_units` makes it easy to take a unit and convert it to the units appropriate for a given locale and usage.\n\nConsider this example:\n\n```elixir\niex> height = Cldr.Unit.new!(1.81, :meter)\n#Cldr.Unit<:meter, 1.81>\n\niex> us_height = Cldr.Unit.localize height, usage: :person_height, territory: :US\n[#Cldr.Unit<:foot, 5>,\n #Cldr.Unit<:inch, 1545635392113553812 <|> 137269716642252725>]\n\niex> Cldr.Unit.to_string us_height\n{:ok, \"5 feet and 11.26 inches\"}\n```\n\nNote that conversion is dependent on context. The context above is `:person_height` reflecting that we are referring to the height of a person. For units of `length` category, the other contexts available are `:rainfall`, `:snowfall`, `:vehicle`, `:visibility` and `:road`. Using the above example with the context of `:rainfall` we see\n\n```elixir\niex> length = Cldr.Unit.localize height, usage: :rainfall, territory: :US\n[#Cldr.Unit<:inch, 9781818390648717312 <|> 137269716642252725>]\n\niex> Cldr.Unit.to_string length\n{:ok, \"71.26 inches\"}\n```\n\nSee `Cldr.Unit.preferred_units/3` to see what mappings are available, in particular what context usage is supported for conversion.","ref":"readme.html#localising-units-for-a-given-locale-or-territory"},{"type":"extras","title":"Unit arithmetic - Cldr for Units","doc":"Basic arithmetic is provided by `Cldr.Unit.add/2`, `Cldr.Unit.sub/2`, `Cldr.Unit.mult/2`, `Cldr.Unit.div/2` as well as `Cldr.Unit.round/3`\n\n```elixir\niex> Cldr.Unit.Math.add Cldr.Unit.new!(:foot, 1), Cldr.Unit.new!(:foot, 1)\n#Cldr.Unit<:foot, 2>\n\niex> Cldr.Unit.Math.add Cldr.Unit.new!(:foot, 1), Cldr.Unit.new!(:mile, 1)\n#Cldr.Unit<:foot, 5280.945925937846>\n\niex> Cldr.Unit.Math.add Cldr.Unit.new!(:foot, 1), Cldr.Unit.new!(:gallon, 1)\n{:error, {Cldr.Unit.IncompatibleUnitError,\n \"Operations can only be performed between units of the same type. Received #Cldr.Unit<:foot, 1> and #Cldr.Unit<:gallon, 1>\"}}\n\niex> Cldr.Unit.round Cldr.Unit.new(:yard, 1031.61), 1\n#Cldr.Unit<:yard, 1031.6>\n\niex> Cldr.Unit.round Cldr.Unit.new(:yard, 1031.61), 1, :up\n#Cldr.Unit<:yard, 1031.7>\n\n```","ref":"readme.html#unit-arithmetic"},{"type":"extras","title":"Available units - Cldr for Units","doc":"Available units are returned by `Cldr.Unit.known_units/0`.\n\n```elixir\niex> Cldr.Unit.known_units\n[:acre, :acre_foot, :ampere, :arc_minute, :arc_second, :astronomical_unit, :bit,\n :bushel, :byte, :calorie, :carat, :celsius, :centiliter, :centimeter, :century,\n :cubic_centimeter, :cubic_foot, :cubic_inch, :cubic_kilometer, :cubic_meter,\n :cubic_mile, :cubic_yard, :cup, :cup_metric, :day, :deciliter, :decimeter,\n :degree, :fahrenheit, :fathom, :fluid_ounce, :foodcalorie, :foot, :furlong,\n :g_force, :gallon, :gallon_imperial, :generic, :gigabit, :gigabyte, :gigahertz,\n :gigawatt, :gram, :hectare, :hectoliter, :hectopascal, :hertz, :horsepower,\n :hour, :inch, ...]\n```","ref":"readme.html#available-units"},{"type":"extras","title":"Unit categories - Cldr for Units","doc":"Units are grouped by unit category which defines the convertibility of different types.  In general, units of the same category are convertible to each other. The function `Cldr.Unit.known_unit_categories/0` returns the unit categories.\n\n```elixir\niex> Cldr.Unit.known_unit_categories\n[:acceleration, :angle, :area, :concentr, :consumption, :coordinate, :digital,\n :duration, :electric, :energy, :frequency, :length, :light, :mass, :power,\n :pressure, :speed, :temperature, :volume]\n```\n\nSee also `Cldr.Unit.known_units_by_category/0` and `Cldr.Unit.known_units_for_category/1`.","ref":"readme.html#unit-categories"},{"type":"extras","title":"Measurement systems - Cldr for Units","doc":"Units generally fall into one of three measurement systems in use around the world. In CLDR these are known as `:metric`, `:ussystem` and `:uksystem`. The following functions allow identifying measurement systems for units, territories and locales.\n\n* The measurement systems are returned with `Cldr.Unit.known_measurement_systems/0`.\n\n* The measurement systems for a given unit are returned by `Cldr.Unit.measurement_systems_for_unit/1`.\n\n* A boolean indicating membership in a given measurement system is returned by `Cldr.Unit.measurement_system?/2`.\n\n* All units belonging to a measurement system are returned by `Cldr.Unit.measurement_system_units/1`.\n\n* The measurement system in use for a given territory is returned by `Cldr.Unit.measurement_system_for_territory/1`.\n\n* The measurement system in use for a given locale is returned by `Cldr.Unit.measurement_system_from_locale/1`.\n\n#### Localisation with measurement systems\n\nKnowledge of the measurement system in place for a given user helps create a better user experience. For example, a user who prefers units of measure in the US system can be shown different but compatible units from a user who prefers metric units.\n\nIn this example, the list of units in the volume category are filtered based upon the users preference as expressed by their locale.\n```elixir\n# For a user preferring US english\niex> system = Cldr.Unit.measurement_system_from_locale \"en\"\n:ussystem\n\niex> {:ok, units} = Cldr.Unit.known_units_for_category(:volume)\niex> Enum.filter(units, &Cldr.Unit.measurement_system?(&1, system))\n[:dessert_spoon, :cup, :drop, :dram, :cubic_foot, :teaspoon, :tablespoon,\n :cubic_inch, :bushel, :quart, :pint, :cubic_yard, :cubic_mile, :fluid_ounce,\n :pinch, :barrel, :jigger, :gallon, :acre_foot]\n\n# For a user preferring australian english\niex> system = Cldr.Unit.measurement_system_from_locale \"en-AU\"\n:metric\n\niex> Enum.filter(units, &Cldr.Unit.measurement_system?(&1, system))\n[:cubic_centimeter, :centiliter, :cubic_meter, :pint_metric, :megaliter,\n :cubic_kilometer, :hectoliter, :milliliter, :deciliter, :liter, :cup_metric]\n\n# For a user expressing an explicit measurement system\niex> system = Cldr.Unit.measurement_system_from_locale \"en-AU-u-ms-uksystem\"\n:uksystem\n\niex> Enum.filter(units, &Cldr.Unit.measurement_system?(&1, system))\n[:quart_imperial, :cubic_foot, :cubic_inch, :dessert_spoon_imperial,\n :cubic_yard, :cubic_mile, :fluid_ounce_imperial, :acre_foot, :gallon_imperial]\n```","ref":"readme.html#measurement-systems"},{"type":"extras","title":"Additional units (custom units) - Cldr for Units","doc":"Additional domain-specific  units can be defined to suit application requirements. In the context\nof `ex_cldr` there are two parts to configuring additional units.\n\n1. Configure the unit, base unit and conversion in `config.exs`. This is a requirement since units are compiled into code.\n\n2. Configure the localizations for the additional unit in a CLDR backend module. Once configured, additional units act and behave like any of the predefined units of measure defined by CLDR.","ref":"readme.html#additional-units-custom-units"},{"type":"extras","title":"Configuring a unit in config.exs - Cldr for Units","doc":"Under the application  `:ex_cldr_units`, define a key `:additional_units` with the required unit\ndefinitions.\n\nFor  example:\n```elixir\nconfig :ex_cldr_units,  :additional_units,\n  vehicle: [base_unit: :unit, factor: 1,  offset: 0, sort_before: :all],\n  person: [base_unit: :unit, factor:  1, offset: 0, sort_before: :all]\n```\nThis example defines  two additional units: `:vehicle` and  `:person`.\n\n* The keys `:base_unit`, and  `:factor` are required. The  key `:offset` is optional and  defaults to `0`.\n\n* The key `:sort_before` is optional and defaults to `:none`.","ref":"readme.html#configuring-a-unit-in-config-exs"},{"type":"extras","title":"Configuration keys - Cldr for Units","doc":"* `:base_unit` is the common denominator that is used to support conversion between like units. It can be any atom value. For example `:liter` is the base unit for volume units, `:meter` is the base unit for length units.\n\n*  `:factor` is used to convert a unit to its base unit in order to support conversion. When converting a unit to another compatible unit, the unit is first  multiplied by this units factor then divided by the target units factor.\n\n* `:offset` is added to a unit after applying its base factor in order to convert to another unit.\n\n* `:sort_before` determines where in this *base unit* sorts relative to other base units. Typically this is set to `:all` in which  case this base unit sorts before all other base units or`:none` in which case this base unit sorted after all other base units. The default is `:none`. If in doubt, leave this key to its default.\n\n*  `:systems` is list of measurement systems to which this unit belongs. The known measurement systems are `:metric`, `:uksystem` and `:ussystem`.  The  default is `[:metric,  :ussystem, :uksystem]`.","ref":"readme.html#configuration-keys"},{"type":"extras","title":"Defining localizations - Cldr for Units","doc":"Although defining a unit in `config.exs` is enough to create, operate on and serialize an additional unit, it cannot be localised without defining localizations in an `ex_cldr` backend module.  For example:\n\n```elixir\ndefmodule MyApp.Cldr do\n  # Note that this line should come before the `use Cldr` line\n  use Cldr.Unit.Additional\n\n  use Cldr,\n    locales: [\"en\", \"fr\", \"de\", \"bs\", \"af\", \"af-NA\", \"se-SE\"],\n    default_locale: \"en\",\n    providers: [Cldr.Number, Cldr.Unit, Cldr.List]\n\n  unit_localization(:person, \"en\", :long,\n    nominative: %{\n      one: \"{0} person\",\n      other: \"{0} people\"\n    },\n    display_name: \"people\"\n  )\nend\n```\n\nNote the additions to a typical `ex_cldr` backend module:\n\n* `use Cldr.Unit.Additional` is required to define additional units\n\n* use of the `Cldr.Unit.Additional.unit_localization/4` macro in order to define a localization.\n\n* The use templates for the localization. Templates are a string with both a placeholder (for units it is always `{0}`) and some fixed text that reflects the grammatical requirements of the particular locale.\n\n* Not all locales support more than the nominative case. The nominative case is the default and mandatory one. Any configured \"Additional Units\" in a backend module will need to put the localisations into a map with the key `:nominative`.\n\nOne invocation of `Cldr.Unit.Additional.unit_localization/4` should made for each combination of unit, locale and style.\n\n#### Parameters to unit_localization/4\n\n* `unit` is the name of the additional unit as an `atom`.\n\n* `locale` is the locale name for this localization. It should be one of the locale configured in this backend although this cannot currently be confirmed at compile time.\n\n* `style` is one of `:long`, `:short`, or `:narrow`.\n\n* `localizations` is a keyword like of localization strings. Two keys - `:display_name` and `:other` are mandatory. They represent the localizations for a non-count display name and `:other` is the localization for a unit when no other pluralization is defined.\n\n#### Localisation definition\n\nLocalization keyword list defines localizations that match the plural rules for a given locale. Plural rules for a given number in a given locale resolve to one of\nsix keys, and they must be placed under the proper declension to be used:\n\n* `:zero`\n* `:one` (singular)\n* `:two` (dual)\n* `:few` (paucal)\n* `:many` (also used for fractions if they have a separate class)\n* `:other` (required — general plural form. Also used if the language only has a single form)\n\nOnly the `:nominative` key is required, and at minimum, it has to provide the `:other` key. For english, providing keys for `:one` and `:other` is enough. Other languages have different grammatical requirements.\n\nThe key `:display_name` is used by the function `Cldr.Unit.display_name/1` which is primarily used to support UI applications.","ref":"readme.html#defining-localizations"},{"type":"extras","title":"Sorting Units - Cldr for Units","doc":"From Elixir 1.10, `Enum.sort/2` supports module-based comparisons to provide a simpler API for sorting structs. `ex_cldr_units` supports Elixir 1.10 as the following example shows:\n```elixir\niex> alias Cldr.Unit\nCldr.Unit\n\niex> unit_list = [Unit.new!(:millimeter, 100), Unit.new!(:centimeter, 100), Unit.new!(:meter, 100), Unit.new!(:kilometer, 100)]\n[#Unit<:millimeter, 100>, #Unit<:centimeter, 100>, #Unit<:meter, 100>,\n #Unit<:kilometer, 100>]\n\niex> Enum.sort unit_list, Cldr.Unit\n[#Unit<:millimeter, 100>, #Unit<:centimeter, 100>, #Unit<:meter, 100>,\n #Unit<:kilometer, 100>]\n\niex> Enum.sort unit_list, {:desc, Cldr.Unit}\n[#Unit<:kilometer, 100>, #Unit<:meter, 100>, #Unit<:centimeter, 100>,\n #Unit<:millimeter, 100>]\n\niex> Enum.sort unit_list, {:asc, Cldr.Unit}\n[#Unit<:millimeter, 100>, #Unit<:centimeter, 100>, #Unit<:meter, 100>,\n #Unit<:kilometer, 100>]\n```\n\nNote that the items being sorted must be all of the same unit category (length, volume, ...). Where units are of the same category but different units, conversion to a common unit will occur before the comparison. If units of different categories are encountered an exception will be raised as the following example shows:\n```elixir\niex> unit_list = [Unit.new!(:millimeter, 100), Unit.new!(:centimeter, 100), Unit.new!(:meter, 100), Unit.new!(:liter, 100)]\n[#Cldr.Unit<:millimeter, 100>, #Cldr.Unit<:centimeter, 100>,\n #Cldr.Unit<:meter, 100>, #Cldr.Unit<:liter, 100>]\n\niex> Enum.sort unit_list, Cldr.Unit\n** (Cldr.Unit.IncompatibleUnitsError) Operations can only be performed between units with the same category and base unit. Received :liter and :meter\n```","ref":"readme.html#sorting-units"},{"type":"extras","title":"Serializing to a database with Ecto - Cldr for Units","doc":"The companion package [ex_cldr_units_sql](https://hex.pm/packages/ex_cldr_units_sql) provides functions for the serialization of `Unit` data.  See the [README](https://hexdocs.pm/ex_cldr_units_sql/readme.html) for further information.","ref":"readme.html#serializing-to-a-database-with-ecto"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Cldr_Units v3.17.1 - Changelog","doc":"This is the changelog for Cldr_units v3.17.1 released on July 30th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-17-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix parsing prefixes that have no unit. Thanks to @maltoe for the report, the patience and the PR. Closes #47.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.17.0 - Changelog","doc":"This is the changelog for Cldr_units v3.17.0 released on April 21st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-17-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes canonical unit name formation. More units can now be resolved to a base unit and therefore compared and converted with other units. The primary change is to add elimination of common factors in \"per\" units.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add conversion support for Beaufort. This conversion is non linear and therefore cannot be expressed using the normal unit conversion method.\n\n* `Cldr.Unit.Math.mult/2` and `Cldr.Unit.Math.div/2` now support scalar values as the second argument. Its therefore now possible to say `Cldr.Unit.Math.mult(Cldr.Unit.new!(:meter, 10), 2)`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.16.5 - Changelog","doc":"This is the changelog for Cldr_units v3.16.4 released on April 11th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-16-5"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix spec for `Cldr.Unit.display_name/2`. Thanks to @ryotsu for the report. Closes #43.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.16.4 - Changelog","doc":"This is the changelog for Cldr_units v3.16.4 released on November 2nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-16-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compiler warnings for Elixir 1.16.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.16.3 - Changelog","doc":"This is the changelog for Cldr_units v3.16.3 released on September 25th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-16-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix use of user-defined units (known as additional units). Closes #40.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.16.2 - Changelog","doc":"This is the changelog for Cldr_units v3.16.2 released on June 15th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-16-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Unit.round/1` for float units. Thanks to @doughsay for the report. Closes #38.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.16.1 - Changelog","doc":"This is the changelog for Cldr_units v3.16.1 released on May 22nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-16-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Assert a defined order of map keys in order to operate correctly on OTP 26.\n\n* Works around an [OTP 26 bug](https://github.com/erlang/otp/pull/7269) when binary pattern matching in function heads.\n\n* Removes a compiler warning in Elixir 1.15 (which is actually a compile error in Elixir 1.15.0-rc.0)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.16.0 - Changelog","doc":"This is the changelog for Cldr_units v3.16.0 released on April 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-16-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Support Decimal version 2.1 and later which raise a different exception that older releases when calling `Decimal.to_integer/1` when the value isn't convertible.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR 43](https://cldr.unicode.org/index/downloads/cldr-43) data. The unit `:beaufort` is introduced but only in some locales.\n\n* Remove the dependency on `ratio`. All unit values are now decimals.\n\n* Support string-formatted decimals in `Cldr.Unit.new/3`. This allows the creation of units like `Cldr.Unit.new(:foot, \"3.39\")` which will also be produced now by the `Inspect` protocol. Apart from the inherent consistency this also improves accuracy will all tests for conversion and preference from CLDR test data now passing.\n\n* Add a `Cldr.Unit.Range` type to allow creating, enumerating and formatting unit ranges. Thanks to @ribanez7 for the collaboration. Closes #33.\n\n* Add support for multiplication and division of arbitrary units. Thanks to @maennchen for the report (and patience). Closes #32.\n\n* Adjust the inspect protocol implementation to emit executable code strings.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.15.0 - Changelog","doc":"This is the changelog for Cldr_units v3.15.0 released on October 24th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-15-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR 42](https://cldr.unicode.org/index/downloads/cldr-42). There are two changes to the unit data:\n  * The length of a light-year has been adjusted to the IAU value (which uses a Julian year of 365.25 days).\n  * The unit ID for metric-tonne has been deprecated in favor of tonne.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.14.0 - Changelog","doc":"This is the changelog for Cldr_units v3.14.0 released on October 8th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-14-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Unit.parse_unit_name/2` to parse a string as unit name. Also adds `MyApp.Cldr.parse_unit_name/2` as well as the `!` versions of these functions.  Thanks to @Awlexus for the PR. Closes #31.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.13.3 - Changelog","doc":"This is the changelog for Cldr_units v3.13.3 released on August 3rd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-13-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix unit comparison for unit values built from decimal strings. Thanks to @seantanly for the report. Closes #29.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.13.2 - Changelog","doc":"This is the changelog for Cldr_units v3.13.2 released on June 7th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-13-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `MyApp.Cldr.Unit.localize/2` which was previously delegating incorrectly to `Cldr.Unit`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.13.1 - Changelog","doc":"This is the changelog for Cldr_units v3.13.1 released on June 7th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-13-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Unit.Math.*` to respect unit `:usage` of the input parameters\n\n* Fix `Cldr.Math.localize/2` to respect unit `:usage` of the options parameter if provided","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.13.0 - Changelog","doc":"This is the changelog for Cldr_units v3.13.0 released on April 6th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-13-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update [CLDR](https://cldr.unicode.org) to [release 41](https://cldr.unicode.org/index/downloads/cldr-41) in [ex_cldr version 2.28.0](https://hex.pm/packages/ex_cldr/2.28.0) and [ex_cldr_numbers 2.26.0](https://hex.pm/packages/ex_cldr_numbers/2.26.0).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.12.2 - Changelog","doc":"This is the changelog for Cldr_units v3.12.2 released on February 27th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-12-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes conversions where the base units don't match (string match) but the units are of the same unit category and therefore are convertible. Thanks to @narrowtux for the report. Fixes #27.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.12.1 - Changelog","doc":"This is the changelog for Cldr_units v3.12.1 released on February 23rd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-12-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove compilation warning for `Phoenix.HTML.Safe` that was emitted since the `:phoenix_html` library is not a dependency. Thanks for @maennchen for the report. Fixes #26.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.12.0 - Changelog","doc":"This is the changelog for Cldr_units v3.12.0 released on February 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-12-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Unit.measurement_system_from_locale/2` to allow the second parameter to be either a backend or a measurement system key.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Unit.from_map/1` to create a unit from a map. This can be used to consume the results of serializing a unit to JSON. The input parameter is designed to mirror the output of the custom Jason encoder.\n\n* Updates to [ex_cldr version 2.26.0](https://hex.pm/packages/ex_cldr/2.26.0) and [ex_cldr_numbers version 2.25.0](https://hex.pm/packages/ex_cldr_numbers/2.25.0) which use atoms for locale names and rbnf locale names. This is consistent with other elements of `t:Cldr.LanguageTag` where atoms are used when the cardinality of the data is fixed and relatively small and strings where the data is free format.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.11.0 - Changelog","doc":"This is the changelog for Cldr_units v3.11.0 released on January 6th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-11-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix canonical base unit calculation when the unit is a `per per` form like `candela per lux`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add unit filters for `Cldr.Unit.parse/2`.  This means that the options `:only` and `:except` can comprise both unit categories and unit names as part of the filter.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.10.0 - Changelog","doc":"This is the changelog for Cldr_units v3.10.0 released on December 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-10-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Further refinement to `Cldr.Unit.unit_category/1` to return a result in a broader range of cases.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `:only` and `:except` options to `Cldr.Unit.parse/2`. These options provide a mechanism to disambiguate the unit when a unit string could refer to more than one unit. For example, \"2w\" could refer to either \"2 weeks\" or \"2 watts\". If neither option is provided then the result is the same as in prior releases: the unit with the lexically shorter and alphabetically earlier unit is returned.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.9.2 - Changelog","doc":"This is the changelog for Cldr_units v3.9.2 released on December 26th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-9-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Unit.unit_category/1`. Thanks to @DaTrader for the report. Closes #24.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.9.1 - Changelog","doc":"This is the changelog for Cldr_units v3.9.1 released on November 15th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-9-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Support parsing units with multiple \"per\" clauses like \"gallon per feet per second\".\n\n* Fix canonical unit name for currency units. This also fixes unit math with currency units.\n\n* Add `display_name/2` to backend modules.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.9.0 - Changelog","doc":"This is the changelog for Cldr_units v3.9.0 released on November 14th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-9-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use `import Config` not deprecated `use Mix.Config` in config files. Only significant for developers of `ex_cldr_units`.\n\n* Make `decimal` a required dependency, not optional, since various pattern matches expect its presence.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for currency-based units.  This allows for calculations and formatting of units such as \"$2 per gallon\". For this example, the unit would be created with `Cldr.Unit.new(2, \"curr-usd-per-gallon\")`. The inverse is also possible, for example:\n\n```elixir\niex> MyApp.Cldr.Unit.to_string(Cldr.Unit.new!(2, \"curr-usd-per-gallon\"))\n{:ok, \"$2.00 per gallon\"}\n\niex> MyApp.Cldr.Unit.to_string(Cldr.Unit.new!(2, \"gallon-per-curr-usd\"))\n{:ok, \"2 gallons per US dollar\"}\n```\n\n* Add support for binary factor prefixed units. These units are factors of 1024 and include \"kibi\", \"mebi\", \"gibi\", \"tebi\", \"pebi\", \"exbi\", \"zebi\" and \"yobi\". For example:\n\n```elixir\niex> MyApp.Cldr.Unit.to_string Cldr.Unit.new!(3, :gibibyte)\n{:ok, \"3 gibibytes\"}\n```\n\n* Add support for integer prefixes for units. This is useful for units like \"liters per 100 kilometers\" or \"25 calories per 100 grams\".  For example:\n\n```elixir\niex> MyApp.Cldr.Unit.to_string Cldr.Unit.new!(25, \"calorie_per_100-gram\")\n{:ok, \"25 calories per 100 grams\"}\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.8.0 - Changelog","doc":"This is the changelog for Cldr_units v3.8.0 released on October 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-8-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to use [CLDR 40](https://cldr.unicode.org/index/downloads/cldr-40) data. The release notes say:\n\n> In CLDR v40, the focus is on Grammatical features (gender and case) for units of measurement in additional locales. In many languages, forming grammatical phrases requires dealing with grammatical gender and case. Without that, it can sound as bad as \"on top of 3 hours\" instead of \"in 3 hours\":\n\n  * Phase 1 (CLDR v39) of grammatical features included just 12 locales (da, de, es, fr, hi, it, nl, no, pl, pt, ru, sv).\n\n  * Phase 2 (CLDR v40, this release) has expanded the number of locales by 29 (am, ar, bn, ca, cs, el, fi, gu, he, hr, hu, hy, is, kn, lt, lv, ml, mr, nb, pa, ro, si, sk, sl, sr, ta, te, uk, ur), but for a more restricted number of units.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.get_locale/2`, use `Cldr.Locale.Loader.get_config/2` instead.\n\n* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Units v3.8.0-rc.2 - Changelog","doc":"This is the changelog for Cldr_units v3.8.0-rc.2 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-8-0-rc-2"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Units v3.8.0-rc.1 - Changelog","doc":"This is the changelog for Cldr_units v3.8.0-rc.1 released on October 24th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-8-0-rc-1"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.get_locale/2`, use `Cldr.Locale.Loader.get_config/2` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Units v3.8.0-rc.0 - Changelog","doc":"This is the changelog for Cldr_units v3.8.0-rc.0 released on October 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-8-0-rc-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to use [CLDR 40](https://cldr.unicode.org/index/downloads/cldr-40) data. The release notes say:\n\nIn CLDR v40, the focus is on Grammatical features (gender and case) for units of measurement in additional locales. In many languages, forming grammatical phrases requires dealing with grammatical gender and case. Without that, it can sound as bad as \"on top of 3 hours\" instead of \"in 3 hours\":\n\n* Phase 1 (CLDR v39) of grammatical features included just 12 locales (da, de, es, fr, hi, it, nl, no, pl, pt, ru, sv).\n* Phase 2 (CLDR v40, this release) has expanded the number of locales by 29 (am, ar, bn, ca, cs, el, fi, gu, he, hr, hu, hy, is, kn, lt, lv, ml, mr, nb, pa, ro, si, sk, sl, sr, ta, te, uk, ur), but for a more restricted number of units.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.7.1 - Changelog","doc":"This is the changelog for Cldr_units v3.7.1 released on August 20th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-7-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix doc errors. Thanks to @maennchen for the report. Doc errors in other `ex_cldr` packages are also updated.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.7.0 - Changelog","doc":"This is the changelog for Cldr_units v3.7.0 released on July 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-7-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for the `Cldr.DisplayName` protocol for `t:Cldr.Unit` structs.\n\n* Updated to [ex_cldr version 2.23.0](https://hex.pm/packages/ex_cldr/2.23.0) which changes the names of some of the fields in the \"-u-\" extension to match the CLDR canonical name. In particular the field name `measurement_system` changes to `ms`. Also the value of `ms` for the UK System will be `:imperial` not `:uksystem`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.6.0 - Changelog","doc":"This is the changelog for Cldr_units v3.6.0 released on June 12th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Unit.parse/2` to parse unit strings of the form `1kg` into a `t:Cldr.Unit` struct.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.5.3 - Changelog","doc":"This is the changelog for Cldr_units v3.5.3 released on May 20th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-5-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes formatting units when invoking `MyApp.Cldr.Unit.to_string/2` (ie on the backend module) and no default backend is configured. Thanks again to @maennchen. Closes #22.  Require at least [ex_cldr version 2.22.1](https://hex.pm/packages/ex_cldr/2.22.1)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.5.2 - Changelog","doc":"This is the changelog for Cldr_units v3.5.2 released on April 12th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-5-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix getting a unit pattern when the unit value is zero, one or two and there is no pattern for the default unit plural category. Thanks to @syfgkjasdkn for the report.  Closes #21.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.5.1 - Changelog","doc":"This is the changelog for Cldr_units v3.5.1 released on April 11th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-5-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use `:other` plural category to format units which have a value of 0, 1 or 2 when the natural unit pattern has no substitutions. This corrects the situation in locales such as `he` and `ar` where the unit pattern for plural category `:one` has no substitutions. Previously this would means the formatted string for a unit with a value of `1` and `-1` would both output the same string.  Thanks to @jarrodmoldrich for the report and to @voltone for his family's help with hebrew grammar.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.5.0 - Changelog","doc":"This is the changelog for Cldr_units v3.5.0 released on April 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-5-0"},{"type":"extras","title":"Overview - Changelog","doc":"In this release the `Cldr.Unit.to_string/{1, 2, 3}` function has been rewritten and the concrete implementation is now in `Cldr.Unit.Format`.  The primary reasons for rewriting are:\n\n1. Improves performance by 20% over the old implementation.\n2. Supports grammatical case and grammatical gender. These allow for better sentence formation in a localised fashion. Only are few locales have the required data for now (for example, `fr` and `de`) however more locales will have data in upcoming CLDR releases.\n\nNote that full testing of grammatical case and grammatical gender variations is not yet complete.","ref":"changelog.html#overview"},{"type":"extras","title":"Soft Deprecation - Changelog","doc":"* The function `Cldr.Unit.to_iolist/{1, 2, 3}` is soft deprecated. It is still available and no deprecation warning is emitted. It will however be removed from the public API in a future release. This function is primarily used to support implementation of `Cldr.Unit.to_string/3`\n\n* As of this release, argument checking in `Cldr.Unit.to_iolist/3` is less rigorous in order to avoid the relatively expensive argument normalization process happening twice (once in `Cldr.Unit.to_string/3` and then again in `Cldr.Unit.to_iolist/3`).","ref":"changelog.html#soft-deprecation"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* The new string formatter correctly assembles units with an SI prefix (ie `millimeter`) in languages such as German where the noun is capitalized.\n\n* Fixes calculating the base unit when the unit is a complex compound unit.\n\n* Remove double parsing when calling `Cldr.Unit.new/2` and the unit is not in `Cldr.Unit.known_units/0`\n\n* Ensure `Cldr.Unit.unit_category/1` returns an error tuple if the category is unknown","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to require [ex_cldr version 2.20](https://hex.pm/packages/ex_cldr/2.20.0) which includes [CLDR 39](http://cldr.unicode.org/index/downloads/cldr-39) data.\n\n* Add `Cldr.Unit.validate_grammatical_gender/2`\n\n* Add `Cldr.Unit.known_grammatical_cases/0`\n\n* Add `Cldr.Unit.known_grammatical_genders/0`\n\n* Add `Cldr.Unit.known_measurement_system_names/0`\n\n* Add `Cldr.Unit.invert/1` to invert a \"per\" unit. This allows for increased compatibility for conversions. For example, \"liters per 100 kilometers\" is a measure of consumption, as is \"miles per gallon\".  However these two units are not convertible without inverting one of them first since one is \"volume per length\" and the other is \"length per volume\".\n\n* Add `Cldr.Unit.conversion_for/2` to return a conversion list used when converting one unit to another.\n\n* Add `Cldr.Unit.grammatical_gender/2` to return the grammatical gender for a given unit and locale\n\n* Add `Cldr.Unit.conversion_for/2` to return a conversion list used when converting one unit to another.\n\n* Add support for grammatical cases for `Cldr.Unit.to_string/2` and `Cldr.Unit.to_iolist/2`. Not all locales support more than the nominative case. The nominative case is the default. Any configured \"Additional Units\" in a backend module will need to be modified to put the localisations a map with the key `:nominative`.  See the readme for more information on migrating additional units.  On example is:\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr.Unit.Additional\n\n  use Cldr,\n    locales: [\"en\", \"fr\", \"de\", \"bs\", \"af\", \"af-NA\", \"se-SE\"],\n    default_locale: \"en\",\n    providers: [Cldr.Number, Cldr.Unit, Cldr.List]\n\n  unit_localization(:person, \"en\", :long,\n    nominative: %{\n      one: \"{0} person\",\n      other: \"{0} people\"\n    },\n    display_name: \"people\"\n  )\nend\n```\n\n* Support conversions where one of the base units is the inverted conversion of the other. This allows conversion between, for example, `mile per gallon` and `liter per 100 kilometer`. These are both compound units of `length` and `volume` but are inverse representations from each other.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.5.0-rc.1 - Changelog","doc":"This is the changelog for Cldr_units v3.5.0-rc.1 released on March 21st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-5-0-rc-1"},{"type":"extras","title":"Overview - Changelog","doc":"In this release the `Cldr.Unit.to_string/{1, 2, 3}` function has been rewritten and the concrete implementation is now in `Cldr.Unit.Format`.  The primary reasons for rewriting are:\n\n1. Improves performance by 20% over the old implementation.\n2. Supports grammatical case and grammatical gender. These allow for better sentence formation in a localised fashion. Only are few locales have the required data for now (for example, `fr` and `de`) however more locales will have data in upcoming CLDR releases.\n\nNote that full testing of grammatical case and grammatical gender variations is not yet complete.","ref":"changelog.html#overview"},{"type":"extras","title":"Soft Deprecation - Changelog","doc":"* The function `Cldr.Unit.to_iolist/{1, 2, 3}` is soft deprecated. It is still available and no deprecation warning is emitted. It will however be removed from the public API in a future release. This function is primarily used to support implementation of `Cldr.Unit.to_string/3`\n\n* As of this release, argument checking in `Cldr.Unit.to_iolist/3` is less rigorous in order to avoid the relatively expensive argument normalization process happening twice (once in `Cldr.Unit.to_string/3` and then again in `Cldr.Unit.to_iolist/3`).","ref":"changelog.html#soft-deprecation"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* The new string formatter correctly assembles units with an SI prefix (ie `millimeter`) in languages such as German where the noun is capitalized.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.5.0-rc.0 - Changelog","doc":"This is the changelog for Cldr_units v3.5.0-rc.0 released on March 19th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-5-0-rc-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes calculating the base unit when the unit is a complex compound unit.\n\n* Remove double parsing when calling `Cldr.Unit.new/2` and the unit is not in `Cldr.Unit.known_units/0`\n\n* Ensure `Cldr.Unit.unit_category/1` returns an error tuple if the category is unknown","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to require [ex_cldr version 2.20](https://hex.pm/packages/ex_cldr/2.20.0) which includes [CLDR 39](http://cldr.unicode.org/index/downloads/cldr-39) data.\n\n* Add `Cldr.Unit.known_grammatical_cases/0`\n\n* Add `Cldr.Unit.known_grammatical_genders/0`\n\n* Add `Cldr.Unit.known_measurement_system_names/0`\n\n* Add `Cldr.Unit.invert/1` to invert a \"per\" unit. This allows for increased compatibility for conversions. For example, \"liters per 100 kilometers\" is a measure of consumption, as is \"miles per gallon\".  However these two units are not convertible without inverting one of them first since one is \"volume per length\" and the other is \"length per volume\".\n\n* Add `Cldr.Unit.conversion_for/2` to return a conversion list used when converting one unit to another.\n\n* Add `Cldr.Unit.grammatical_gender/2` to return the grammatical gender for a given unit and locale\n\n* Add `Cldr.Unit.conversion_for/2` to return a conversion list used when converting one unit to another.\n\n* Add support for grammatical cases for `Cldr.Unit.to_string/2` and `Cldr.Unit.to_iolist/2`. Not all locales support more than the nominative case. The nominative case is the default. Any configured \"Additional Units\" in a backend module will need to be modified to put the localisations a map with the key `:nominative`.  See the readme for more information on migrating additional units.  On example is:\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr.Unit.Additional\n\n  use Cldr,\n    locales: [\"en\", \"fr\", \"de\", \"bs\", \"af\", \"af-NA\", \"se-SE\"],\n    default_locale: \"en\",\n    providers: [Cldr.Number, Cldr.Unit, Cldr.List]\n\n  unit_localization(:person, \"en\", :long,\n    nominative: %{\n      one: \"{0} person\",\n      other: \"{0} people\"\n    },\n    display_name: \"people\"\n  )\nend\n```\n\n* Support conversions where one of the base units is the inverted conversion of the other. This allows conversion between, for example, `mile per gallon` and `liter per 100 kilometer`. These are both compound units of `length` and `volume` but are inverse representations from each other.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.4.0 - Changelog","doc":"This is the changelog for Cldr_units v3.4.0 released on February 9th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-4-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix readme example for `MyApp.Cldr.Unit.convert/2`.  Thanks to @DamienFF. Closes #16.\n\n* Add missing ` .convert!/2`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Supports the definition of custom units in `config.exs`.\n\n* Add `Cldr.Unit.display_name/2`\n\n* Add `Cldr.Unit.known_units_by_category/0`\n\n* Add `Cldr.Unit.known_units_for_category/1`\n\n* Add `Cldr.Unit.measurement_system_units/0`\n\n* Add `Cldr.Unit.measurement_system_from_locale/{2, 3}`\n\n* Add `Cldr.Unit.measurement_system_for_territory/1`\n\n* Add `Cldr.Unit.measurement_systems_for_unit/1`\n\n* Improve `Cldr.Unit.IncompatibleUnit` exception error message\n\n* Deprecate `Cldr.Unit.measurement_systems/0` in favour of `Cldr.Unit.measurement_systems_by_territory/0`\n\n* Requires `ex_cldr` version `~> 2.19` which includes the localised display name of units","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.3.1 - Changelog","doc":"This is the changelog for Cldr_units v3.3.1 released on November 3rd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-3-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Unit.localize/2` when no options are provided","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.3.0 - Changelog","doc":"This is the changelog for Cldr_units v3.3.0 released on November 1st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to [CLDR38](http://cldr.unicode.org/index/downloads/cldr-38)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v3.2.1 - Changelog","doc":"This is the changelog for Cldr_units v3.2.1 released on September 26th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-2-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use `Cldr.default_backend!/0` when available (as in later ex_cldr releases) since `Cldr.default_backend/0` is deprecated.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.2.0 - Changelog","doc":"This is the changelog for Cldr_units v3.2.0 released on September 5th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support string form of unit usage when passed as option `:usage` to `Cldr.Unit.new/3`. This is required to support improved serialization in [ex_cldr_units_sql](https://hex.pm/packages/ex_cldr_units_sql)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correct the documentation to reflect the option `:usage` to `Cldr.Unit.new/3` rather than the incorrect `:use`.\n\n* Fix spec for `Cldr.Units.compatible?/2`. Thanks to @lostkobrakai.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.1.2 - Changelog","doc":"This is the changelog for Cldr_units v3.1.2 released on August 29th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-1-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes dialyzer warning on `Cldr.Unit.to_string/3` and `Cldr.Unit.to_string!/3`. Thanks to @maennchen for the report. Closes #15.\n\n* Support `Decimal` numbers in `Cldr.Unit.to_string/3` and `Cldr.Unit.to_string!/3`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.1.1 - Changelog","doc":"This is the changelog for Cldr_units v3.1.1 released on June 29th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-1-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Ensure that `:locale` is passed through to `Cldr.Number.to_string/3`. Thanks for the PR to @Zurga. Closes #14.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.1.0 - Changelog","doc":"This is the changelog for Cldr_units v3.1.0 released on May 18th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Unit.to_iolist/3` and `Cldr.Unit.to_iolist!/3` to return the formatted unit as an iolist rather than a string. This allows for formatting the number and the unit name differently. It also allows some efficiency in inserting formatted content into a Phoenix workflow since it handles iolists efficiently.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix resolving translatable unit names from strings\n\n* Fix converting translatable units that have a \"per\" conversion","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.0.1 - Changelog","doc":"This is the changelog for Cldr_units v3.0.1 released on May 15th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-0-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Corrects unit creation when the unit itself is directly translatable (like `:kilowatt_hour`) but there is no explicit conversion, just an implicit calculated conversion. Thanks to @syfgkjasdkn.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v3.0.0 - Changelog","doc":"This is the changelog for Cldr_units v3.0.0 released on May 4th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v3-0-0"},{"type":"extras","title":"Summary - Changelog","doc":"* New unit creation including rational numbers\n\n* Base unit calculation\n\n* New unit preferences\n\n* New conversion engine","ref":"changelog.html#summary"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* `Cldr.Unit.new/2` is now `Cldr.Unit/{2, 3}` and it returns a standard `{:ok, unit}` tuple on success. Use `Cldr.Unit.new!/{2,3}` if you want to retain the previous behaviour.\n\n* Removed `Cldr.Unit.unit_tree/0`\n\n* Removed `Cldr.Unit.units/1`\n\n* Removed `Cldr.Unit.compatible_units/2`\n\n* Removed `Cldr.Unit.best_match/1`\n\n* Removed `Cldr.Unit.jaro_match/1`\n\n* Removed `Cldr.Unit.unit_category_map/0` (replaced with `Cldr.Unit.base_unit_category_map/0`)","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Deprecate `Cldr.Unit.unit_categories/0` in favour of `Cldr.Unit.known_unit_categories/0` to be consistent across CLDR.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Incorporate CLDR's unit conversion data into the new conversion engine\n\n* Unit values may now be rational numbers.  Conversion data and the results of conversions are executed and retained as rationals. New units can be created with integer, float, Decimal or rational numbers. Conversion to floats is done only when the unit is output via `Cldr.Unit.to_string/3` or explicitly through the new function `Cldr.Unit.ratio_to_float/1`\n\n* Add an option `:usage` to `Cldr.Unit.new/{2,3}`. This defines an expected usage for a given unit that will be applied during localization. The default is `:default`. See `Cldr.Unit.unit_category_map/0` for what usage is defined for a unit category.\n\n* Add `Cldr.Unit.known_measurement_sytems/0` to return the known measurement systems\n\n* Add `Cldr.Unit.Conversion.preferred_units/3` that returns a list of preferred units for a given unit. This makes it straight forward to take a unit and convert it to the units preferred by the user for a given unit type, locale and use case.\n\n* Add `Cldr.Unit.base_category_map/0` that maps base units to their unit categories. For example, map `mile_per_hour` to `:speed` or `kilogram_square_meter_per_cubic_second_ampere` to `:voltage`. Base units are derived from a unit name and are not normally the concern of the consumer of `ex_cldr_units`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.8.1 - Changelog","doc":"This is the changelog for Cldr_units v2.8.1 released on April 25th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-8-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates data management to be compatible with data from both both CLDR 36 (ex_cldr 2.13) and CLDR 37 (ex_cldr 2.14)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.8.0 - Changelog","doc":"This is the changelog for Cldr_units v2.8.0 released on January 27th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-8-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support the new `Enum.sort/2` in Elixir 1.10. The function `Cldr.Math.cmp/2` is deprecated in favour of `Cldr.Math.compare/2` that has the same function signature and returns the same result that is compatible with Elixir 1.10.\n\n* Adds `Cldr.Unit.compare/2` that is required for `Enum.sort/2` to work as expected with units.\n\nAs an example:\n```\niex> alias Cldr.Unit                                                                             Cldr.Unit\n\niex> unit_list = [Unit.new(:millimeter, 100), Unit.new(:centimeter, 100), Unit.new(:meter, 100), Unit.new(:kilometer, 100)]\n[#Unit<:millimeter, 100>, #Unit<:centimeter, 100>, #Unit<:meter, 100>,\n #Unit<:kilometer, 100>]\n\niex> Enum.sort unit_list, Cldr.Unit\n[#Unit<:millimeter, 100>, #Unit<:centimeter, 100>, #Unit<:meter, 100>,\n #Unit<:kilometer, 100>]\n\niex> Enum.sort unit_list, {:desc, Cldr.Unit}\n[#Unit<:kilometer, 100>, #Unit<:meter, 100>, #Unit<:centimeter, 100>,\n #Unit<:millimeter, 100>]\n\niex> Enum.sort unit_list, {:asc, Cldr.Unit}\n[#Unit<:millimeter, 100>, #Unit<:centimeter, 100>, #Unit<:meter, 100>,\n #Unit<:kilometer, 100>]\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.7.0 - Changelog","doc":"This is the changelog for Cldr_units v2.7.0 released on October 10th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-7-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update [ex_cldr](https://github.com/elixir-cldr/cldr) to version `2.11.0` which encapsulates [CLDR](https://cldr.unicode.org) version `36.0.0` data.\n\n* Update minimum Elixir version to `1.6`\n\n* Adds conversion for `newton meter`, `dalton`, `solar luminosity`, `pound foot`, `bar`, `newton`, `electron volt`, `barrel`, `dunam`, `decade`, `mole`, `pound force`, `megapascal`, `pascal`, `kilopascal`, `solar radius`, `therm US`, `British thermal unit`, `earth mass`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.6.1 - Changelog","doc":"This is the changelog for Cldr_units v2.6.1 released on August 31st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-6-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Unit.to_string/3` to ensure that `{:ok, string}` is returned when formatting a list of units","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v2.6.0 - Changelog","doc":"This is the changelog for Cldr_units v2.6.0 released on August 25th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Unit.localize/3` to support converting a given unit into units that are familiar to a given territory. For example, given a unit of `#Unit<2, :meter>` is would normally be expected to show this as `[#Unit<:foot, 5>, #Unit<:inch, 11>]`. The data to support these conversions is returned by `Cldr.Unit.unit_preferences/0`. An example:\n\n```elixir\n  iex> height = Cldr.Unit.new(1.8, :meter)\n  iex> Cldr.Unit.localize height, :person, territory: :US, style: :informal\n  [#Unit<:foot, 5>, #Unit<:inch, 11>]\n```\n\n  * Note that conversion is dependent on context. The context above is `:person` reflecting that we are referring to the height of a person. For units of `length` category, the other contexts available are `:rainfall`, `:snowfall`, `:vehicle`, `:visibility` and `:road`. Using the above example with the context of `:rainfall` we see\n\n```elixir\n  iex> Cldr.Unit.localize height, :rainfall, territory: :US\n  [#Unit<:inch, 71>]\n```\n\n* Adds a `:per` option to `Cldr.Unit.to_string/3`. This option leverages the `per` formatting style to allow compound units to be printed.  For example, assume want to emit a string which represents \"kilograms per second\". There is no such unit defined in CLDR (or perhaps anywhere!). But if we define the unit `unit = Cldr.Unit.new(:kilogram, 20)` we can then execute `Cldr.Unit.to_string(unit, per: :second)`.  Each locale defines a specific way to format such a compound unit.  Usually it will return something like `20 kilograms/second`\n\n* Adds `Cldr.Unit.unit_preferences/0` to map units into a territory preference alternative unit\n\n* Adds `Cldr.Unit.measurement_systems/0` that identifies the unit system in use for a territory\n\n* Adds `Cldr.Unit.measurement_system_for/1` that returns the measurement system in use for a given territory.  The result will be one of `:metric`, `:US` or `:UK`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Deprecation - Changelog","doc":"* Add `Cldr.Unit.unit_category/1` and deprecate `Cldr.Unit.unit_type/1` in order to be consistent with the nomenclature of CLDR","ref":"changelog.html#deprecation"},{"type":"extras","title":"Cldr_Units v2.5.3 - Changelog","doc":"This is the changelog for Cldr_units v2.5.3 released on August 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-5-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `@spec` for `Cldr.Unit.to_string/3` and `Cldr.Unit.to_string!/3`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v2.5.2 - Changelog","doc":"This is the changelog for Cldr_units v2.5.2 released on August 21st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-5-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Replace `Cldr.get_current_locale/0` with `Cldr.get_locale/0`in docs\n\n* Fix dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v2.5.1 - Changelog","doc":"This is the changelog for Cldr_units v2.5.1 released on June 18th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-5-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Standardize the development cldr backend as `MyApp.Cldr` which makes for more understandable and readable examples and doc tests\n\n* `Cldr.Unit.to_string/3` now allows for the `backend` parameter to default to `Cldr.default_backend/0`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.5.0 - Changelog","doc":"This is the changelog for Cldr_units v2.5.0 released on March 28th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR version 35.0.0](http://cldr.unicode.org/index/downloads/cldr-35) released on March 27th 2019.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.4.0 - Changelog","doc":"This is the changelog for Cldr_units v2.4.0 released on March 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Supports `Cldr.default_backend()` as a default for `backend` parameters in `Cldr.Unit`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.3.3 - Changelog","doc":"This is the changelog for Cldr_units v2.3.2 released on March 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-3-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Include `priv` directory in the hex package (that's where the conversion json exists)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v2.3.2 - Changelog","doc":"This is the changelog for Cldr_units v2.3.2 released on March 20th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-3-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Units v2.3.1 - Changelog","doc":"This is the changelog for Cldr_units v2.3.1 released on March 15th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-3-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Makes generation of documentation for backend modules optional.  This is implemented by the `:generate_docs` option to the backend configuration.  The default is `true`. For example:\n\n```\ndefmodule MyApp.Cldr do\n  use Cldr,\n    default_locale: \"en-001\",\n    locales: [\"en\", \"ja\"],\n    gettext: MyApp.Gettext,\n    generate_docs: false\nend\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.3.0 - Changelog","doc":"This is the changelog for Cldr_units v2.3.0 released on March 4th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* The conversion tables are now stored as json and updates may be downloaded at any time with the mix task `mix cldr.unit.download`. This means that updates to the conversion table may be made without requiring a new release of `Cldr.Unit`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.2.0 - Changelog","doc":"This is the changelog for Cldr_units v2.2.0 released on February 24th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"This release is primarily about improving the conversion of units without introducing precision errors that accumulate for floats. The strategy is to define the conversion value between individual unit pairs.\n\nCurrently the implementation uses a static map.  In order to give users a better experience a future release will allow for both specifying mappings as a parameter to `Cldr.Unit.convert/2` and as compile time configuration options including the option to download conversion tables from the internet.\n\n* Direct conversions are now supported. For some calculations, the process of diving and multiplying by conversion factors produces an unexpected result. Some direct conversions are now defined which produce a more expected result.\n\n* In most cases, return integer values from conversion and decomposition when the originating unit value is also an integer","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.1.0 - Changelog","doc":"This is the changelog for Cldr_units v2.1.0 released on December 8th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Unit.Conversion.convert!/2`\n\n* Add `Cldr.Unit.Math.cmp/2`\n\n* Add `Cldr.Unit.decompose/2`\n\n* Add `Cldr.Unit.zero/1`\n\n* Add `Cldr.Unit.zero?/1`\n\nThe appropriate backend equivalents are also added.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Units v2.0.0 - Changelog","doc":"This is the changelog for Cldr_units v2.0.0 released on November 24th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_units/tags)","ref":"changelog.html#cldr_units-v2-0-0"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* `Cldr.Unit` now requires a `Cldr` backend module to be configured\n\n* In order for the `String.Chars` protocol to be supported (which is used in string interpolation and by `Kernel.to_string/1`) a default backend must be configured.  For example in `config.exs`:\n```\nconfig :ex_cldr_units,\n  default_backend: MyApp.Cldr\n```","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Move to a backend module structure with [ex_cldr](https://hex.pm/packages/ex_cldr) version 2.0","ref":"changelog.html#enhancements"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"},{"type":"extras","title":"License - LICENSE","doc":"Copyright 2017-2024 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}